/************************************************************************
   CompositionAdjustmentRegressions.do
   3/27/14
  Hannah Herman

   Performs composition adjustment regressions

   *********************************************************************/

clear all
set more off

adopath + ado


*Uncertainty Forecast Regressions

matrix define Independent = (9,8,12,11,15,14)
matrix define Dependent = (18,29,21,30,24,31)


*Initialize matrices to save Rbar^2s
foreach type in gdp hicp urate {
forvalues i=1/6 {
		local Ind = Independent[1,`i']
		local Dep = Dependent[1,`i']
		
		matrix `type'_Unc_Fore_`Dep'_`Ind' = J(6,1,.)
}
}

*Loop through variable types and sample cuts to run regressions	
local varlist gdp hicp urate
foreach type in `varlist' {
local j = 1
foreach sampcut in 5 10 15 20 25 100 {
	disp "`type'"
	
	*The first sample restriction is equal to the full data
	import excel using output/results/`type'_full_`sampcut'.xlsx, clear
	local i = 1
	foreach var of varlist * {
		rename `var' v`i'
		local i = `i' + 1
	}
	destring *, replace
	drop if v1 == 2014

	*replace gdp to missing for 2009Q1 for certain variables. 
	if "`type'" == "gdp" {
		replace v18 = . if v1 == 2009 & v2 == 1 
		//replace v29 = . if v1 == 2009 & v2 == 1 
	}

	

	forvalues i=1/6 {
	
		preserve

			local Ind = Independent[1,`i']
			local Dep = Dependent[1,`i']
		
			*drop missing values 
			drop if v`Ind' == . 
			drop if v`Dep' ==.

			reg v`Dep' v`Ind'
			matrix `type'_Unc_Fore_`Dep'_`Ind'[`j',1] = e(r2_a)
			
		restore
	}
	
	local j = `j' + 1
	
} //end sample cut loop
} //end variable type loop
local varlist gdp hicp urate
foreach type in `varlist' {
	*Initialize datasets
	clear
	svmat `type'_Unc_Fore_18_9
	rename `type'_Unc_Fore_18_91 `type'_Unc_Fore_18_9
	gen RequiredResponses = ([_n]-1)*5
	replace RequiredResponses = 1 if RequiredResponses==0
	sort RequiredResponses
	save output/regressions/`type'_Unc_Fore_Comp.dta, replace 

	forvalues i=2/6 {
		local Ind = Independent[1,`i']
		disp `Ind'
		local Dep = Dependent[1,`i']
		disp `Dep'
		
		clear
		svmat `type'_Unc_Fore_`Dep'_`Ind'
		rename `type'_Unc_Fore_`Dep'_`Ind'1 `type'_Unc_Fore_`Dep'_`Ind'
		gen RequiredResponses = ([_n]-1)*5
		replace RequiredResponses = 1 if RequiredResponses==0
		sort RequiredResponses
		merge 1:1 RequiredResponses using output/regressions/`type'_Unc_Fore_Comp.dta
		drop _merge
		save output/regressions/`type'_Unc_Fore_Comp.dta, replace 		
	}	
	
	use output/regressions/`type'_Unc_Fore_Comp.dta, clear
	order RequiredResponses
	if "`type'" == "gdp" {
		export excel using output/regressions/Unc_Fore_Comp.xlsx, sheet(`type') replace firstrow(variables)
	}
	else {
		export excel using output/regressions/Unc_Fore_Comp.xlsx, sheet(`type') firstrow(variables)
	}
}

/************************************
*Accuarcy Uncertainty Regressions 
*************************************/

matrix define Independent = (18,18,18,29,29,29)
matrix define Dependent = (36,37,35,33,34,32)

*Initialize matrices to save Rbar^2s
foreach type in gdp hicp urate {
forvalues i=1/6 {
		local Ind = Independent[1,`i']
		local Dep = Dependent[1,`i']
		
		matrix `type'_Acc_Unc_`Dep'_`Ind' = J(6,1,.)
}
}

*Loop through variable types and sample cuts to run regressions	
local varlist gdp hicp urate
foreach type in `varlist' {
local j = 1
foreach sampcut in 5 10 15 20 25 100 {
	disp "`type'"
	
	*The first sample restriction is equal to the full data
	import excel using output/results/`type'_full_`sampcut'.xlsx, clear
	local i = 1
	foreach var of varlist * {
		rename `var' v`i'
		local i = `i' + 1
	}
	destring *, replace
	drop if v1 == 2014

	*replace gdp to missing for 2009Q1 for certain variables. 
	if "`type'" == "gdp" {
		replace v18 = . if v1 == 2009 & v2 == 1 
		//replace v29 = . if v1 == 2009 & v2 == 1 
	}

	

	forvalues i=1/6 {
	
		preserve

			local Ind = Independent[1,`i']
			local Dep = Dependent[1,`i']
			
			*square independent variable
			replace v`Ind' = v`Ind'^2
		
			*drop missing values 
			drop if v`Ind' == . 
			drop if v`Dep' ==.

			reg v`Dep' v`Ind'
			matrix `type'_Acc_Unc_`Dep'_`Ind'[`j',1] = e(r2_a)
			
		restore
	}
	
	local j = `j' + 1
	
} //end sample cut loop
} //end variable type loop
set more off
local varlist gdp hicp urate
foreach type in `varlist' {
	*Initialize datasets
	clear
	svmat `type'_Acc_Unc_36_18
	rename `type'_Acc_Unc_36_181 `type'_Acc_Unc_36_18
	gen RequiredResponses = ([_n]-1)*5
	replace RequiredResponses = 1 if RequiredResponses==0
	sort RequiredResponses
	save output/regressions/`type'_Acc_Unc_Comp.dta, replace 

	forvalues i=2/6 {
		local Ind = Independent[1,`i']
		disp `Ind'
		local Dep = Dependent[1,`i']
		disp `Dep'
		
		clear
		svmat `type'_Acc_Unc_`Dep'_`Ind'
		rename `type'_Acc_Unc_`Dep'_`Ind'1 `type'_Acc_Unc_`Dep'_`Ind'
		gen RequiredResponses = ([_n]-1)*5
		replace RequiredResponses = 1 if RequiredResponses==0
		sort RequiredResponses
		merge 1:1 RequiredResponses using output/regressions/`type'_Acc_Unc_Comp.dta
		drop _merge
		save output/regressions/`type'_Acc_Unc_Comp.dta, replace 		
	}	
	
	use output/regressions/`type'_Acc_Unc_Comp.dta, clear
	order RequiredResponses
	if "`type'" == "gdp" {
		export excel using output/regressions/Acc_Unc_Comp.xlsx, sheet(`type') replace firstrow(variables)
	}
	else {
		export excel using output/regressions/Acc_Unc_Comp.xlsx, sheet(`type') firstrow(variables)
	}
}


/*****************************************	
*Uncertainty Disagreement Regressions
******************************************/


matrix define Independent = (19,10,22,13,25,16)
matrix define Dependent = (18,29,21,30,24,31)
	
*Initialize matrices to save Rbar^2s
foreach type in gdp hicp urate {
forvalues i=1/6 {
		local Ind = Independent[1,`i']
		local Dep = Dependent[1,`i']
		
		matrix `type'_Unc_Dis_`Dep'_`Ind' = J(6,1,.)
}
}

*Loop through variable types and sample cuts to run regressions	
local varlist gdp hicp urate
foreach type in `varlist' {
local j = 1
foreach sampcut in 5 10 15 20 25 100 {
	disp "`type'"
	
	*The first sample restriction is equal to the full data
	import excel using output/results/`type'_full_`sampcut'.xlsx, clear
	local i = 1
	foreach var of varlist * {
		rename `var' v`i'
		local i = `i' + 1
	}
	destring *, replace
	drop if v1 == 2014

	*replace gdp to missing for 2009Q1 for certain variables. 
	if "`type'" == "gdp" {
		replace v18 = . if v1 == 2009 & v2 == 1 
		//replace v29 = . if v1 == 2009 & v2 == 1 
	}

	

	forvalues i=1/6 {
	
		preserve

			local Ind = Independent[1,`i']
			local Dep = Dependent[1,`i']
		
			*drop missing values 
			drop if v`Ind' == . 
			drop if v`Dep' ==.

			reg v`Dep' v`Ind'
			matrix `type'_Unc_Dis_`Dep'_`Ind'[`j',1] = e(r2_a)
			
		restore
	}
	
	local j = `j' + 1
	
} //end sample cut loop
} //end variable type loop
set more off
local varlist gdp hicp urate
foreach type in `varlist' {
	*Initialize datasets
	clear
	svmat `type'_Unc_Dis_18_19
	rename `type'_Unc_Dis_18_191 `type'_Unc_Dis_18_19
	gen RequiredResponses = ([_n]-1)*5
	replace RequiredResponses = 1 if RequiredResponses==0
	sort RequiredResponses
	save output/regressions/`type'_Unc_Dis_Comp.dta, replace 

	forvalues i=2/6 {
		local Ind = Independent[1,`i']
		disp `Ind'
		local Dep = Dependent[1,`i']
		disp `Dep'
		
		clear
		svmat `type'_Unc_Dis_`Dep'_`Ind'
		rename `type'_Unc_Dis_`Dep'_`Ind'1 `type'_Unc_Dis_`Dep'_`Ind'
		gen RequiredResponses = ([_n]-1)*5
		replace RequiredResponses = 1 if RequiredResponses==0
		sort RequiredResponses
		merge 1:1 RequiredResponses using output/regressions/`type'_Unc_Dis_Comp.dta
		drop _merge
		save output/regressions/`type'_Unc_Dis_Comp.dta, replace 		
	}	
	
	use output/regressions/`type'_Unc_Dis_Comp.dta, clear
	order RequiredResponses
	if "`type'" == "gdp" {
		export excel using output/regressions/Unc_Dis_Comp.xlsx, sheet(`type') replace firstrow(variables)
	}
	else {
		export excel using output/regressions/Unc_Dis_Comp.xlsx, sheet(`type') firstrow(variables)
	}
}
