*************************************************************************************
* Master.do
* 
* By:       Matthew Ploenzke
* For:      Robert Rich and Joe Tracy
* Created:  09.25.2014

************************************************************************************
/* 
Master script prepared for the Journal of Applied Econometrics.

NOTE: Change the home directory to rerun the program and reproduce the results.
Also change global file paths at the beginning of the RawData_shell.do file.

Upon completion, submit the following programs to RATS in order to produce 
the correlations in Table 1 and Table 1A. Make sure to edit the path 
referenced in each file.
	1. GDP.prg
	2. HICP.prg
	3. UN.prg

Home directory: </san/rds/Derived/cei/SPF/ECB/JAE>
Inputs: data/raw/
Outputs: output/results/

*/
version 13
// Edit this path here, everything else is referenced from this:
cd /san/rds/Derived/cei/SPF/ECB/JAE
/*================================ Preamble ======================================*/
cap log close
clear all
set more off
program drop _all
file close _all
est clear
log using programs/logs/master_log.smcl, replace

/*============================ Data Preparation ==================================*/
// Import Raw Files
do programs/RawData_shell.do
// GDP
do programs/Midpoint_GDP_shell.do
// HICP
do programs/Midpoint_HICP_shell.do
// Unemployment Rate
do programs/Midpoint_Urate_shell.do

/*==================== Calculate Individual Uncertainty ==========================*/
// HICP
do programs/Individual_Uncertainty_HICP.do
// GDP
do programs/Individual_Uncertainty_GDP.do
// Unemployment Rate
do programs/Individual_Uncertainty_Urate.do

/*======== Create Percentiles by Individual Forecast Distribution ================*/
// HICP
do programs/Tail_Bin_Count_HICP.do
// GDP
do programs/Tail_Bin_Count_GDP.do
// Unemployment Rate
do programs/Tail_Bin_Count_Urate.do

/*================== Calculate Z&L Individual Uncertainty ========================*/
do programs/ZL.do

/*============== Import Realized Data and Perform Regressions ====================*/
do programs/PullData.do

/*============ Calculate Number of Respondents for Web Appendix =================*/
do programs/TotalResponses.do

/*========================= Perform Regressions =================================*/
//Uncertainty Disagreement
do programs/Unc_Dis_Regressions.do
// Accuracy Uncertainty
do programs/Accuracy_Unc_Regressions.do
//Uncertainty Point Prediction
do programs/Unc_Fore_Regressions.do
// Composition Adjustment
do programs/CompositionAdjustmentRegressions.do


log close
