/************************************************************
Program Name: Midpoint.do
Program Creator: Joseph Song
Date: 4-16-2010
Description: Creates mean and variance using the midpoint formula

input: urateA.dta
       urateB.dta

output: urateA.dta
        urateB.dta

Creates "diagnostic" variables which we can use to exclude
individual forecasters. foreach  in "" {

   }
   
//////////// IMPORTANT ////////////
Assumes that the leftmost and rightmost bins (open intervals)
are doubled so they have a width of 1.
***************************************************************/

clear all

foreach x in urateAroll urateBroll uratefiveyr {
	use $data/`x'.dta, clear

	/* Creates Midpoints of each bin */
	/* Number of bins differ across time */
	   
	forvalues x = 1/21 {
		gen mid`x' = .
	}

	*	Group 1:  1999-Q1 to 2001-Q1
		replace mid1 = 8.5 if group == 1
		replace mid2 = 9.2 if group == 1

		forvalues x = 3/21 {
			local y = `x' - 1
			replace mid`x' = mid`y' + 0.5 if group == 1 & `x' <= 13
			replace mid`x' = 15.5 if group == 1 & `x' == 14
			replace mid`x' = . if group == 1 & `x' >= 15
		}
		
	*	Group 2:  2000-Q2
		replace mid1 = 7.0 if group == 2
		replace mid2 = 7.7 if group == 2

		forvalues x = 3/21 {
			local y = `x' - 1
			replace mid`x' = mid`y' + 0.5 if group == 2 & `x' <= 16
			replace mid`x' = 15.5 if group == 2 & `x' == 17
			replace mid`x' = . if group == 2 & `x' >= 18
		}
		
	*	Group 3:  2000-Q3 to 2000-Q4   
		replace mid1 = 6.5 if group == 3
		replace mid2 = 7.2 if group == 3

		forvalues x = 3/21 {
			local y = `x' - 1
			replace mid`x' = mid`y' + 0.5 if group == 3 & `x' <= 10
			replace mid`x' = 12 if group == 3 & `x' == 11
			replace mid`x' = . if group == 3 & `x' >= 12
		}

	*	Group 4:  2001-Q1 to 2002-Q1
		replace mid1 = 6.0 if group == 4
		replace mid2 = 6.7 if group == 4

		forvalues x = 3/21 {
			local y = `x' - 1
			replace mid`x' = mid`y' + 0.5 if group == 4 & `x' <= 18
			replace mid`x' = 15.5 if group == 4 & `x' == 19
			replace mid`x' = . if group == 4 & `x' >= 20
		}

	*	Group 5:  2002-Q2 to 2009-Q1
		replace mid1 = 5.0 if group == 5 | group == 6
		replace mid2 = 5.7 if group == 5 | group == 6

		forvalues x = 3/21 {
			local y = `x' - 1
			replace mid`x' = mid`y' + 0.5 if group == 5 & `x' <= 12
			replace mid`x' = 11.5 if group == 5 & `x' == 13
			replace mid`x' = . if group == 5 & `x' >= 14
		}

	*	Group 6: 2009-Q2 to 2009-Q4
		forvalues x = 3/21 {
			local y = `x' - 1
			replace mid`x' = mid`y' + 0.5 if group == 6 & `x' <= 20
			replace mid`x' = 15.5 if group == 6 & `x' == 21
		}

	*	Group 7:  2010-Q1 to 2013-Q4 (and beyond)
		replace mid1 = 6.0 if group == 7
		replace mid2 = 6.7 if group == 7

		forvalues x = 3/21 {
			local y = `x' - 1
			replace mid`x' = mid`y' + 0.5 if group == 7 & `x' <= 18
			replace mid`x' = 15.5 if group == 7 & `x' == 19
			replace mid`x' = . if group == 7 & `x' >= 20
		}
	   
	gen mmid = a1*mid1 + a2*mid2 + a3*mid3 + a4*mid4 + a5*mid5 + a6*mid6 + a7*mid7 + a8*mid8 + a9*mid9 + a10*mid10 + a11*mid11 + a12*mid12 + a13*mid13 + a14*mid14 if group == 1
	replace mmid = a1*mid1 + a2*mid2 + a3*mid3 + a4*mid4 + a5*mid5 + a6*mid6 + a7*mid7 + a8*mid8 + a9*mid9 + a10*mid10 + a11*mid11 + a12*mid12 + a13*mid13 + a14*mid14 + a15*mid15 + a16*mid16 + a17*mid17 if group == 2
	replace mmid = a1*mid1 + a2*mid2 + a3*mid3 + a4*mid4 + a5*mid5 + a6*mid6 + a7*mid7 + a8*mid8 + a9*mid9 + a10*mid10 + a11*mid11  if group == 3
	replace mmid = a1*mid1 + a2*mid2 + a3*mid3 + a4*mid4 + a5*mid5 + a6*mid6 + a7*mid7 + a8*mid8 + a9*mid9 + a10*mid10 + a11*mid11 + a12*mid12 + a13*mid13 + a14*mid14 + a15*mid15 + a16*mid16 + a17*mid17 + a18*mid18 + a19*mid19 if group == 4
	replace mmid = a1*mid1 + a2*mid2 + a3*mid3 + a4*mid4 + a5*mid5 + a6*mid6 + a7*mid7 + a8*mid8 + a9*mid9 + a10*mid10 + a11*mid11 + a12*mid12 + a13*mid13 if group == 5
	replace mmid = a1*mid1 + a2*mid2 + a3*mid3 + a4*mid4 + a5*mid5 + a6*mid6 + a7*mid7 + a8*mid8 + a9*mid9 + a10*mid10 + a11*mid11 + a12*mid12 + a13*mid13 + a14*mid14 + a15*mid15 + a16*mid16 + a17*mid17 + a18*mid18 + a19*mid19 + a20*mid20 + a21*mid21 if group == 6
	replace mmid = a1*mid1 + a2*mid2 + a3*mid3 + a4*mid4 + a5*mid5 + a6*mid6 + a7*mid7 + a8*mid8 + a9*mid9 + a10*mid10 + a11*mid11 + a12*mid12 + a13*mid13 + a14*mid14 + a15*mid15 + a16*mid16 + a17*mid17 + a18*mid18 + a19*mid19 if group == 7

	gen vmid = a1*(mid1-mmid)^2 + a2*(mid2-mmid)^2 + a3*(mid3-mmid)^2 + a4*(mid4-mmid)^2 + a5*(mid5-mmid)^2 + a6*(mid6-mmid)^2 + a7*(mid7-mmid)^2 + a8*(mid8-mmid)^2 + a9*(mid9-mmid)^2 + a10*(mid10-mmid)^2 + a11*(mid11-mmid)^2 + a12*(mid12-mmid)^2 + a13*(mid13-mmid)^2 + a14*(mid14-mmid)^2 if group == 1
	replace vmid = a1*(mid1-mmid)^2 + a2*(mid2-mmid)^2 + a3*(mid3-mmid)^2 + a4*(mid4-mmid)^2 + a5*(mid5-mmid)^2 + a6*(mid6-mmid)^2 + a7*(mid7-mmid)^2 + a8*(mid8-mmid)^2 + a9*(mid9-mmid)^2 + a10*(mid10-mmid)^2 + a11*(mid11-mmid)^2 + a12*(mid12-mmid)^2 + a13*(mid13-mmid)^2 + a14*(mid14-mmid)^2 + a15*(mid15-mmid)^2 + a16*(mid16-mmid)^2 + a17*(mid17-mmid)^2 if group == 2
	replace vmid = a1*(mid1-mmid)^2 + a2*(mid2-mmid)^2 + a3*(mid3-mmid)^2 + a4*(mid4-mmid)^2 + a5*(mid5-mmid)^2 + a6*(mid6-mmid)^2 + a7*(mid7-mmid)^2 + a8*(mid8-mmid)^2 + a9*(mid9-mmid)^2 + a10*(mid10-mmid)^2 + a11*(mid11-mmid)^2 if group == 3
	replace vmid = a1*(mid1-mmid)^2 + a2*(mid2-mmid)^2 + a3*(mid3-mmid)^2 + a4*(mid4-mmid)^2 + a5*(mid5-mmid)^2 + a6*(mid6-mmid)^2 + a7*(mid7-mmid)^2 + a8*(mid8-mmid)^2 + a9*(mid9-mmid)^2 + a10*(mid10-mmid)^2 + a11*(mid11-mmid)^2 + a12*(mid12-mmid)^2 + a13*(mid13-mmid)^2 + a14*(mid14-mmid)^2 + a15*(mid15-mmid)^2 + a16*(mid16-mmid)^2 + a17*(mid17-mmid)^2 + a18*(mid18-mmid)^2 + a19*(mid19-mmid)^2 if group == 4
	replace vmid = a1*(mid1-mmid)^2 + a2*(mid2-mmid)^2 + a3*(mid3-mmid)^2 + a4*(mid4-mmid)^2 + a5*(mid5-mmid)^2 + a6*(mid6-mmid)^2 + a7*(mid7-mmid)^2 + a8*(mid8-mmid)^2 + a9*(mid9-mmid)^2 + a10*(mid10-mmid)^2 + a11*(mid11-mmid)^2 + a12*(mid12-mmid)^2 + a13*(mid13-mmid)^2 if group == 5
	replace vmid = a1*(mid1-mmid)^2 + a2*(mid2-mmid)^2 + a3*(mid3-mmid)^2 + a4*(mid4-mmid)^2 + a5*(mid5-mmid)^2 + a6*(mid6-mmid)^2 + a7*(mid7-mmid)^2 + a8*(mid8-mmid)^2 + a9*(mid9-mmid)^2 + a10*(mid10-mmid)^2 + a11*(mid11-mmid)^2 + a12*(mid12-mmid)^2 + a13*(mid13-mmid)^2 + a14*(mid14-mmid)^2 + a15*(mid15-mmid)^2 + a16*(mid16-mmid)^2 + a17*(mid17-mmid)^2 + a18*(mid18-mmid)^2 + a19*(mid19-mmid)^2 + a20*(mid20-mmid)^2 + a21*(mid21-mmid)^2 if group == 6
	replace vmid = a1*(mid1-mmid)^2 + a2*(mid2-mmid)^2 + a3*(mid3-mmid)^2 + a4*(mid4-mmid)^2 + a5*(mid5-mmid)^2 + a6*(mid6-mmid)^2 + a7*(mid7-mmid)^2 + a8*(mid8-mmid)^2 + a9*(mid9-mmid)^2 + a10*(mid10-mmid)^2 + a11*(mid11-mmid)^2 + a12*(mid12-mmid)^2 + a13*(mid13-mmid)^2 + a14*(mid14-mmid)^2 + a15*(mid15-mmid)^2 + a16*(mid16-mmid)^2 + a17*(mid17-mmid)^2 + a18*(mid18-mmid)^2 + a19*(mid19-mmid)^2 if group == 7

	gen smid = sqrt(vmid)

	drop mid*

	label var mmid "Mean of the density forecast using the midpoint formula"
	label var vmid "Variance of the density forecast using the midpoint formula"
	label var smid "Standard Deviation of the density forecast using the midpoint formula"
	   
	gen nopoint = 0
	replace nopoint = 1 if point == .

	egen total = rowtotal(a1-a21)

	gen sum0 = 0
	replace sum0 = 1 if total == 0
	   
	label variable sum0 "missing density forecast"

	gen sum1 = 0
	replace sum1=1 if total <=.991  | total >=1.009
	label variable sum1 "probabilities do not sum to unity"

	gen kooky = 0
	replace kooky=1 if abs(mmid-point)>0.5 & sum1==0 & sum0==0 & nopoint==0
	label variable kooky "discrepancy between point and density forecasts greater than 1.5%"

	save, replace
}

cd $main

foreach file in gdpAroll gdpBroll gdpfiveyr hicpAroll hicpBroll hicpfiveyr urateAroll urateBroll uratefiveyr {
	use  output/tempfiles/`file'.dta, clear
	save             data/`file'.dta, replace
}

