/************************************************************************
   PullData.do
   Kaivan K. Sattar - 11/6/2013
   Hannah Herman - 3/27/2014

   Description: Calculate realized values of Euro zone GDP growth and HICP, then
   combine various series into speradsheets for Hicp, GDP and urate

*********************************************************************/
clear all
set more off

/* Not effected by composition adjustment. Just Run them once. */
*	1. Raw HICP data ; 2010-Q1 = Dec-2009 -- Dec-2010
	import excel using data/raw/EuroData.xlsx, sheet("hicp") clear
	drop if _n <= 1
	gen year = substr(A,1,4)
	gen month = substr(A,5,2)
	destring month year C, replace
	rename C hicp
	sort year month
	*create realized growth rate variable for long term forecast 
	gen temp1 = 100*((hicp[_n+11]-hicp[_n])/hicp[_n])  // for long run want Jan-Dec growth rate
	by year: gen temp2 = temp1 if month==12
	by year: egen temp3 = total(temp2), missing
	drop temp1 temp2 A B
	keep if month == 12 | month == 3 | month == 6 | month == 9
	keep if year >= 1998
	rename month quarter
	replace quarter = 1 if quarter == 3
	replace quarter = 2 if quarter == 6
	replace quarter = 3 if quarter == 9
	replace quarter = 4 if quarter == 12
	*	This adjustment is made because of the way the HICP survey question is asked
	* 	in 1998Q1 the variable they are asked to forecast is inflation from Dec 1997 to Dec 1998
		gen realized_hicp_growthA = 100*((hicp[_n+3]-hicp[_n-1])/hicp[_n-1])
		gen realized_hicp_growthB = 100*((hicp[_n+7]-hicp[_n+3])/hicp[_n+3])
		gen realized_hicp_growth5 = temp3[_n+18]
	drop temp3 hicp
	keep if year > 1998
	rename year ydate
	rename quarter qdate
	save output/hicp/hicp, replace
	
*	2.1 Raw GDP growth data ; 2010-Q1 = 2009-Q3 -- 2010-Q3
	import excel using data/raw/EuroData.xlsx, sheet("gdp") clear
	drop if _n <= 1
	gen year = substr(A,1,4)
	gen quarter = substr(A,5,1)
	destring year quarter C, replace
	rename C gdp
	sort year quarter
	*create realized growth rate variable for long term forecast 
	gen temp1 = 100*((gdp[_n+3]-gdp[_n])/gdp[_n])
	by year: gen temp2 = temp1 if quarter==4
	by year: egen temp3 = total(temp2), missing
	drop temp1 temp2 A B
	keep if year >= 1998
	*	This adjustment is made because of the way the GDP survey question is asked
	* 	In 1998Q1 they are asked to forecast gdp growth from 1997Q3 to 1998Q3
		gen realized_gdp_growthA = 100 * ((gdp[_n+2]-gdp[_n-2]) / gdp[_n-2])
		gen realized_gdp_growthB = 100 * ((gdp[_n+6]-gdp[_n+2]) / gdp[_n+2])
		gen realized_gdp_growth5 = temp3[_n+18]	
	drop temp3 gdp
	keep if year > 1998
	rename year ydate
	rename quarter qdate		
	save output/gdp/gdp, replace
	
* 	2.2 Raw Urate data 
	import excel using data/raw/EuroData.xlsx, sheet("urate") clear
	drop if _n <= 1
	gen year = substr(A,1,4)
	gen month = substr(A,5,2)
	destring month year C, replace
	rename C urate
	sort year month
	*create realized variable for long term forecast 
	by year: egen temp = mean(urate)
	keep if month == 11 | month == 2 | month == 5 | month == 8
	keep if year >= 1998
	rename month quarter
	replace quarter = 1 if quarter == 2
	replace quarter = 2 if quarter == 5
	replace quarter = 3 if quarter == 8
	replace quarter = 4 if quarter == 11
	*	This adjustment is made because of the way the HICP survey question is asked
	*	In 1998Q1 you are asked to forecast the unemployment rate in Nov of '98. 
		gen realized_urateA = (urate[_n+3])
		gen realized_urateB = (urate[_n+7])
		gen realized_urate5 = (temp[_n+18])	
	drop urate temp A B
	keep if year > 1998	
	rename year ydate
	rename quarter qdate	
	save output/urate/urate, replace
	
foreach sampcut in 5 10 15 20 25 100 {
*	3. Read in HICP & GDP, one year ahead data
*	A. Mean and median forecasts
	foreach type in HICP GDP urate {
		foreach horizon in A B {
			local low = lower("`type'")
			use data/`low'`horizon'roll.dta, clear
			bys person: gen sample_N = _N
			if `sampcut' != 100 {
   				drop if sample_N < `sampcut'
   			}
			drop if nopoint | sum1 | sum0
			preserve
			collapse (mean) point = point (p50) p50point = point (sd) sdpoint = point, by(ydate qdate)
			ren point `low'_meanfore`horizon'
			ren p50point `low'_medianfore`horizon'
			ren sdpoint `low'_SDfore`horizon'
			save output/tempfiles/temp_`low'_mean_`horizon', replace
			restore
		}
		use data/`low'fiveyr.dta, clear
		bys person: gen sample_N = _N
		if `sampcut' != 100 {
   				drop if sample_N < `sampcut'
   			}
		drop if nopoint | sum1 | sum0
		preserve
		collapse (mean) point = point (p50) p50point = point (sd) sdpoint = point, by(ydate qdate)
		ren point `low'_meanforefiveyr
		ren p50point `low'_medianforefiveyr
		ren sdpoint `low'_SDforefiveyr
		save output/tempfiles/temp_`low'_mean_fiveyr, replace
		restore
	}
	
	
*	B. IQR Uncertainty and Disagreement
*	GDP
	insheet using output/gdp/laxgdp_PercentileA_iqr_`sampcut'.csv, clear
	keep ydate qdate iqr_mean iqr_uncertainty_med iqr_disagreement
	ren iqr_mean iqr_gdp_uncert_meanA
	ren iqr_uncertainty_med iqr_gdp_uncert_medA
	ren iqr_disagreement iqr_gdp_disagA
	save output/tempfiles/temp_gdp_iqrA, replace
	
	insheet using output/gdp/laxgdp_PercentileB_iqr_`sampcut'.csv, clear
	keep ydate qdate iqr_mean iqr_uncertainty_med iqr_disagreement
	ren iqr_mean iqr_gdp_uncert_meanB
	ren iqr_uncertainty_med iqr_gdp_uncert_medB
	ren iqr_disagreement iqr_gdp_disagB
	save output/tempfiles/temp_gdp_iqrB, replace
	
	*for 5 yr horizon added by HH
	insheet using output/gdp/laxgdp_Percentile5_iqr_`sampcut'.csv, clear
	keep ydate qdate iqr_mean iqr_uncertainty_med iqr_disagreement
	ren iqr_mean iqr_gdp_uncert_mean5
	ren iqr_uncertainty_med iqr_gdp_uncert_med5
	ren iqr_disagreement iqr_gdp_disag5
	save output/tempfiles/temp_gdp_iqr5, replace

*	HICP
	insheet using output/hicp/laxhicp_PercentileA_iqr_`sampcut'.csv, clear
	keep ydate qdate iqr_mean iqr_uncertainty_med iqr_disagreement
	ren iqr_mean iqr_hicp_uncert_meanA
	ren iqr_uncertainty_med iqr_hicp_uncert_medA
	ren iqr_disagreement iqr_hicp_disagA
	save output/tempfiles/temp_hicp_iqrA, replace
	
	insheet using output/hicp/laxhicp_PercentileB_iqr_`sampcut'.csv, clear
	keep ydate qdate iqr_mean iqr_uncertainty_med iqr_disagreement
	ren iqr_mean iqr_hicp_uncert_meanB
	ren iqr_uncertainty_med iqr_hicp_uncert_medB
	ren iqr_disagreement iqr_hicp_disagB
	save output/tempfiles/temp_hicp_iqrB, replace
	
	*for 5 yr horizon added by HH
	insheet using output/hicp/laxhicp_Percentile5_iqr_`sampcut'.csv, clear
	keep ydate qdate iqr_mean iqr_uncertainty_med iqr_disagreement
	ren iqr_mean iqr_hicp_uncert_mean5
	ren iqr_uncertainty_med iqr_hicp_uncert_med5
	ren iqr_disagreement iqr_hicp_disag5
	save output/tempfiles/temp_hicp_iqr5, replace
	
*	Urate
	insheet using output/urate/laxurate_PercentileA_iqr_`sampcut'.csv, clear
	keep ydate qdate iqr_mean iqr_uncertainty_med iqr_disagreement
	ren iqr_mean iqr_urate_uncert_meanA
	ren iqr_uncertainty_med iqr_urate_uncert_medA
	ren iqr_disagreement iqr_urate_disagA
	save output/tempfiles/temp_urate_iqrA, replace
	
	insheet using output/urate/laxurate_PercentileB_iqr_`sampcut'.csv, clear
	keep ydate qdate iqr_mean iqr_uncertainty_med iqr_disagreement
	ren iqr_mean iqr_urate_uncert_meanB
	ren iqr_uncertainty_med iqr_urate_uncert_medB
	ren iqr_disagreement iqr_urate_disagB
	save output/tempfiles/temp_urate_iqrB, replace
	
	*for 5 yr horizon added by HH
	insheet using output/urate/laxurate_Percentile5_iqr_`sampcut'.csv, clear
	keep ydate qdate iqr_mean iqr_uncertainty_med iqr_disagreement
	ren iqr_mean iqr_urate_uncert_mean5
	ren iqr_uncertainty_med iqr_urate_uncert_med5
	ren iqr_disagreement iqr_urate_disag5
	save output/tempfiles/temp_urate_iqr5, replace
	
	
*	3.D Z&L measures
	foreach type in HICP GDP Urate {
		local low = lower("`type'")
		*mean
		use output/`low'/ZL_`type'_mean_`sampcut'.dta, clear
		keep ydate qdate ZL_SD_`type'*
		rename ZL_SD_`type'_A ZL_`type'_mean_A
		rename ZL_SD_`type'_B ZL_`type'_mean_B
		rename ZL_SD_`type'_5 ZL_`type'_mean_5
		save output/tempfiles/temp_mean_ZL_`type', replace
		*median
		use output/`low'/ZL_`type'_median_`sampcut'.dta, clear
		keep ydate qdate ZL_SD_`type'*
		rename ZL_SD_`type'_A ZL_`type'_median_A
		rename ZL_SD_`type'_B ZL_`type'_median_B
		rename ZL_SD_`type'_5 ZL_`type'_median_5
		save output/tempfiles/temp_median_ZL_`type', replace 
	}
	
	
* 	4. Add quarterly GDP growth for all variables. 
*	4.1 Raw GDP growth data ; 2010-Q1 = 2009-Q3 -- 2010-Q3
	import excel using data/raw/EuroData.xlsx, sheet("gdp") clear
	drop if _n <= 1
	gen year = substr(A,1,4)
	gen quarter = substr(A,5,1)
	destring year quarter C, replace
	rename C gdp
	sort year quarter
	*calc growth rate
	gen gdp_growth = 100*((gdp[_n]-gdp[_n-1])/gdp[_n-1])
	drop gdp A B
	rename quarter qdate
	rename year ydate
	keep if ydate > 1998	
	save output/tempfiles/temp_GDP_growth.dta, replace
	
* 	4.2 Raw Urate data 
	import excel using data/raw/EuroData.xlsx, sheet("urate") clear
	drop if _n <= 1
	gen year = substr(A,1,4)
	gen month = substr(A,5,2)
	destring month year C, replace
	rename C urate
	sort year month
	*create 3 month average of u rate
	gen urate_3mavg = (urate[_n] + urate[_n-1] + urate[_n-2])/3
	drop urate A B
	keep if month == 12 | month == 3 | month == 6 | month == 9
	keep if year >= 1998
	rename month quarter
	replace quarter = 1 if quarter == 3
	replace quarter = 2 if quarter == 6
	replace quarter = 3 if quarter == 9
	replace quarter = 4 if quarter == 12
	rename quarter qdate
	rename year ydate
	keep if ydate > 1998	
	save output/tempfiles/temp_Urate.dta, replace 
	
*	5. Calculate individual forecast errors 
* 	   for each one year ahead survey we want x_e = 1/N*(sum_{i:1toN}(X_i - X_realized)^2) where 
*		X_i is individual i's forecast and N is the number of forecasters

	foreach type in HICP GDP urate {
		local low = lower("`type'")	
		use data/`low'Aroll.dta, clear	
		*Restrict sample
		bys person: gen sample_N = _N
		if `sampcut' != 100 {
   			drop if sample_N < `sampcut'
   		}
		drop if nopoint | sum1 | sum0
		merge m:1 ydate qdate using output/`low'/`low'
		keep ydate qdate point realized*A
		gen error = (realized - point)^2
		drop point realized
		collapse (mean) error (median) med_error = error, by(ydate qdate)
		rename error mean_error_individual_`low'A
		rename med_error median_error_individual_`low'A
		save output/tempfiles/temp_error_individual_`low', replace
		}

*	6. Merge all data sets
*	GDP
	use output/gdp/gdp, clear
	foreach file in temp_GDP_growth temp_Urate temp_gdp_mean_A temp_gdp_mean_B temp_gdp_mean_fiveyr temp_gdp_iqrA temp_gdp_iqrB  ///
	   temp_gdp_iqr5 temp_median_ZL_GDP temp_mean_ZL_GDP temp_error_individual_gdp {
		merge m:1 ydate qdate using output/tempfiles/`file'
		qui summ _merge
		if `r(min)' != 3 {
			disp "Merging error in `file'"
		}
		drop _merge
	}
	*Generate forecast error using mean and median point forecast
	gen error_mean_gdpA = (realized_gdp_growthA - gdp_meanforeA)^2
	gen error_median_gdpA = (realized_gdp_growthA - gdp_medianforeA)^2
	*Generate squared residuals from regressing realized value on mean & median forecasts 
		*mean
		reg realized_gdp_growthA gdp_meanforeA
		predict mean_residuals_gdpA, residuals 
		replace mean_residuals_gdpA = mean_residuals_gdpA^2
		*median
		reg realized_gdp_growthA gdp_medianforeA
		predict median_residuals_gdpA, residuals 
		replace median_residuals_gdpA = median_residuals_gdpA^2
	*order variables in dataset 
	order  ydate qdate realized_gdp_growthA realized_gdp_growthB realized_gdp_growth5 gdp_growth ///
		urate_3mavg	gdp_meanforeA gdp_medianforeA gdp_SDforeA gdp_meanforeB gdp_medianforeB gdp_SDforeB ///
		gdp_meanforefiveyr gdp_medianforefiveyr gdp_SDforefiveyr iqr_gdp_uncert_meanA iqr_gdp_uncert_medA ///
		iqr_gdp_disagA iqr_gdp_uncert_meanB iqr_gdp_uncert_medB iqr_gdp_disagB iqr_gdp_uncert_mean5	/// 
		iqr_gdp_uncert_med5 iqr_gdp_disag5 ZL_GDP_median_A ZL_GDP_median_B ZL_GDP_median_5 ZL_GDP_mean_A ZL_GDP_mean_B ///
		ZL_GDP_mean_5 mean_error_individual_gdpA error_mean_gdpA mean_residuals_gdpA median_error_individual_gdpA ///
		error_median_gdpA median_residuals_gdpA 
	*Output data sheets
	save output/results/gdp_full_`sampcut', replace
	export excel using output/results/gdp_full_`sampcut'.xlsx, replace
	
*	HICP
	use output/hicp/hicp, clear
	foreach file in temp_GDP_growth temp_Urate temp_hicp_mean_A temp_hicp_mean_B temp_hicp_mean_fiveyr temp_hicp_iqrA temp_hicp_iqrB  ///
	   temp_hicp_iqr5 temp_median_ZL_HICP temp_mean_ZL_HICP  temp_error_individual_hicp{
		merge m:1 ydate qdate using output/tempfiles/`file'
		qui summ _merge
		if `r(min)' != 3 {
			disp "Merging error in `file'"
		}
		drop _merge
	}
	*Generate forecast error using mean and median point forecast
	gen error_mean_hicpA = (realized_hicp_growthA-hicp_meanforeA)^2
	gen error_median_hicpA = (realized_hicp_growthA - hicp_medianforeA)^2
	*Generate squared residuals from regressing realized value on mean & median forecasts 
		*mean
		reg realized_hicp_growthA hicp_meanforeA
		predict mean_residuals_hicpA, residuals 
		replace mean_residuals_hicpA = mean_residuals_hicpA^2
		*median
		reg realized_hicp_growthA hicp_medianforeA
		predict median_residuals_hicpA, residuals 
		replace median_residuals_hicpA = median_residuals_hicpA^2
	*order variables in dataset 
	order  ydate qdate realized_hicp_growthA realized_hicp_growthB realized_hicp_growth5 gdp_growth ///
		urate_3mavg	hicp_meanforeA hicp_medianforeA hicp_SDforeA hicp_meanforeB hicp_medianforeB hicp_SDforeB ///
		hicp_meanforefiveyr hicp_medianforefiveyr hicp_SDforefiveyr iqr_hicp_uncert_meanA iqr_hicp_uncert_medA ///
		iqr_hicp_disagA iqr_hicp_uncert_meanB iqr_hicp_uncert_medB iqr_hicp_disagB iqr_hicp_uncert_mean5	/// 
		iqr_hicp_uncert_med5 iqr_hicp_disag5 ZL_HICP_median_A ZL_HICP_median_B ZL_HICP_median_5 ZL_HICP_mean_A ZL_HICP_mean_B ///
		ZL_HICP_mean_5 mean_error_individual_hicpA error_mean_hicpA mean_residuals_hicpA median_error_individual_hicpA ///
		error_median_hicpA median_residuals_hicpA 
	*Output data sheets
	save output/results/hicp_full_`sampcut', replace
	export excel using output/results/hicp_full_`sampcut'.xlsx, replace
	
*	urate
	use output/urate/urate
	foreach file in temp_GDP_growth temp_Urate temp_urate_mean_A temp_urate_mean_B temp_urate_mean_fiveyr temp_urate_iqrA ///
	   temp_urate_iqrB temp_urate_iqr5 temp_median_ZL_Urate temp_mean_ZL_Urate temp_error_individual_urate {
		merge m:1 ydate qdate using output/tempfiles/`file'
		qui summ _merge
		if `r(min)' != 3 {
			disp "Merging error in `file'"
		}
		drop _merge
	}
	*Generate forecast error using mean and median point forecast
	gen error_mean_urateA = (realized_urateA - urate_meanforeA)^2
	gen error_median_urateA = (realized_urateA - urate_medianforeA)^2
	*Generate squared residuals from regressing realized value on mean & median forecasts 
		*mean
		reg realized_urateA urate_meanforeA
		predict mean_residuals_urateA, residuals 
		replace mean_residuals_urateA = mean_residuals_urateA^2
		*median
		reg realized_urateA urate_medianforeA
		predict median_residuals_urateA, residuals 
		replace median_residuals_urateA = median_residuals_urateA^2
	*order variables in dataset
	order  ydate qdate realized_urateA realized_urateB realized_urate5 gdp_growth ///
		urate_3mavg	urate_meanforeA urate_medianforeA urate_SDforeA urate_meanforeB urate_medianforeB urate_SDforeB ///
		urate_meanforefiveyr urate_medianforefiveyr urate_SDforefiveyr iqr_urate_uncert_meanA iqr_urate_uncert_medA ///
		iqr_urate_disagA iqr_urate_uncert_meanB iqr_urate_uncert_medB iqr_urate_disagB iqr_urate_uncert_mean5	/// 
		iqr_urate_uncert_med5 iqr_urate_disag5 ZL_Urate_median_A ZL_Urate_median_B ZL_Urate_median_5 ///
		ZL_Urate_mean_A ZL_Urate_mean_B ZL_Urate_mean_5 mean_error_individual_urateA error_mean_urateA ///
		mean_residuals_urateA median_error_individual_urateA error_median_urateA median_residuals_urateA
	*Output data sheets
	save output/results/urate_full_`sampcut', replace
	export excel using output/results/urate_full_`sampcut'.xlsx, replace 
} //end sample cut loop

*	6. Erase intermediate files
	*gdp
	foreach x in temp_gdp_mean_A temp_gdp_mean_B temp_gdp_mean_fiveyr  ///
	 temp_gdp_iqrA temp_gdp_iqrB temp_gdp_iqr5 ///
	temp_median_ZL_GDP temp_mean_ZL_GDP temp_error_individual_gdp {
		erase output/tempfiles/`x'.dta
	}
	
	*hicp
	foreach x in temp_hicp_mean_A temp_hicp_mean_B temp_hicp_mean_fiveyr  ///
	temp_hicp_iqrA temp_hicp_iqrB temp_hicp_iqr5 ///
	temp_median_ZL_HICP temp_mean_ZL_HICP temp_error_individual_hicp {
		erase output/tempfiles/`x'.dta
	}

	*urate
	foreach x in temp_urate_mean_A temp_urate_mean_B temp_urate_mean_fiveyr  ///
	temp_urate_iqrA temp_urate_iqrB temp_urate_iqr5 /// 
	temp_median_ZL_Urate temp_mean_ZL_Urate temp_error_individual_urate {
		erase output/tempfiles/`x'.dta
	}

