/********************************************************************
   Data in: /Data/Raw Data/SPF_`year'Q`quarter'.csv files from the ECB (RAW DATA)
   
   Data out: /Data/Clean Data/ECB/hicpA.dta
             hicpB.dta
             hicpAroll.dta
             hicpBroll.dta
             hicptwoyr.dta
             hicpfiveyr.dta
             gdpA.dta
             gdpB.dta
             gdpAroll.dta
             gdpBroll.dta
             gdptwoyr.dta
             gdpfivetr.dta
             urateA.dta
             urateB.dta
             urateAroll.dta
             urateBroll.dta
             uratetwoyr.dta
             uratefiveyr.dta
   *******************************************************************************/
	
	global raw       /san/RDS/Derived/cei/SPF/ECB/JAE/data/raw        
	global main      /san/RDS/Derived/cei/SPF/ECB/JAE
	global data      /san/RDS/Derived/cei/SPF/ECB/JAE/output/tempfiles
	global finaldata /san/RDS/Derived/cei/SPF/ECB/JAE/data/
*	start = first possible survey date
*	end = current survey
*	next = next quarter
	global start_year    = 1999
	global start_quarter = 1
	global end_year      = 2013
	global end_quarter   = 4
	global next_year     = 2014
	global next_quarter  = 1
   
clear
set more off

*log using "datalog.log", replace

local year = $start_year /* set starting year */
local quarter = $start_quarter /* set starting quarter */
local z = 0 /*set dummy to trigger to get out of loop */

while `z' == 0 {

   insheet using "$raw/SPF_`year'Q`quarter'.csv", comma  clear

   /*Get rid of header */
   drop in 1/2

   preserve

   /* Mark where the GDP data section starts */
   gen GDP = strpos(v1, "GDP")
   gen binGDP = 0
   replace binGDP = 1 if GDP > 0

   /* Keep only inflation data */
   gen erasedata = sum(binGDP)
   drop if erasedata == 1

   rename v1 date
   rename v2 person
   rename v3 point

   drop GDP binGDP erasedata

   /* Create Date (year & month) Variables */
   gen year = substr(date,1,4)
   gen temp = substr(date,5,3)

   destring v* person point year,replace
   gen month = .
   replace month = 12 if temp == "Dec"
   replace month = 3 if temp == "Mar"
   replace month = 6 if temp == "Jun"
   replace month = 9 if temp == "Sep"

   tab month, missing
   drop date temp
   gen qdate = `quarter' /*survey date (quarter)*/
   gen ydate = `year' /* survey date (year)*/
   order ydate qdate year month
   save "$data/temp_inflation_`year'Q`quarter'.dta", replace

   restore
   preserve
   /*Keep GDP data */
   
   gen GDP = strpos(v1, "GDP")
   gen binGDP = 0
   replace binGDP = 1 if GDP > 0

   gen keepdata = sum(binGDP)
   keep if keepdata == 1

   gen labour = strpos(v1, "LABOUR")
   gen binlabour = 0
   replace binlabour = 1 if labour > 0
   gen erasedata = sum(binlabour)
   drop if erasedata == 1

   /* Get rid of header*/
   drop in 1/2

   rename v1 date
   rename v2 person
   rename v3 point

   drop GDP binGDP keepdata labour binlabour erasedata

   /* Create date variables (year & quarter)*/
   gen year = substr(date,1,4)
   gen quarter = substr(date,6,1)

   destring v* person point year quarter, replace
   drop date
   gen qdate = `quarter' /*survey date (quarter)*/
   gen ydate = `year' /*survey date (year)*/
   order ydate qdate year quarter
   save "$data/temp_GDP_`year'Q`quarter'.dta", replace

   restore

   /*Keep Unemployment Data */
   gen urate = strpos(v1, "UNEMPLOYMENT")
   gen binurate = 0
   replace binurate = 1 if urate >0
   gen keepdata = sum(binurate)
   keep if keepdata == 1

   /* Drop Assumption Data */
   gen assume = strpos(v1, "ASSUMPTIONS")
   gen binassume = 0
   replace binassume = 1 if assume > 0
   gen erasedata = sum(binassume)
   drop if erasedata == 1

   drop in 1/2
   rename v1 date
   rename v2 person
   rename v3 point
   drop urate binurate keepdata assume binassume erasedata
   gen year = substr(date, 1,4)
   gen temp = substr(date,5,3)

   destring v* person point year,replace
   gen month = .
   replace month = 11 if temp == "Nov"
   replace month = 2 if temp == "Feb"
   replace month = 5 if temp == "May"
   replace month = 8 if temp == "Aug"
   
   replace month = 12 if temp == "Dec"
   replace month = 3 if temp == "Mar"
   replace month = 6 if temp == "Jun"
   replace month = 9 if temp == "Sep"

   tab month, missing
   drop date temp
   gen qdate = `quarter' /*survey date (quarter)*/
   gen ydate = `year' /* survey date (year)*/
   order ydate qdate year month
   save "$data/temp_unemployment_`year'Q`quarter'.dta", replace
   
   
/*****************************************************************************************/
/*****************************************************************************************/
/*****************************************************************************************/
   
   /*Change Date Here!!!!!!!! Should be the date of the most recent dataset*/
   if (`year' == $end_year & `quarter' == $end_quarter) {
      local z = 1
   }
   
   local quarter = `quarter' + 1

   if `quarter' == 5 {
      local year = `year' + 1
      local quarter = 1
   }
}

/*Parse & append the data by forecast horizons */

local year = $start_year /*set year*/
local quarter = $start_quarter /*set quarter*/
local z = 0 /*set dummy*/

while `z' == 0 {
   
   use "$data/temp_inflation_`year'Q`quarter'.dta", clear
   
   capture confirm numeric variable year
   if _rc {
	drop if year == "TARG"
   }
   
   destring year, replace
   destring person, replace
   
   /********************************************************************/
   /* Create Dummies by forecast horizons                              */
   /********************************************************************/
   
   /*Current Calendar Year Horizon Dummy */
   gen hicpA = 0
   replace hicpA = 1 if (year == `year' & month == .)
   label var hicpA "Current Year HICP Inflation Expectation"
   
   /* Next Calendar Year Horizon Dummy */
   gen hicpB = 0
   replace hicpB = 1 if (year == `year' + 1 & month == .)
   label var hicpB "Next Year HICP Inflation Expectation"
   
   /* One Year Ahead Rolling Horizon Dummy */
   gen hicpAroll = 0
   replace hicpAroll = 1 if (qdate == 1 & year == `year' & month != .)
   replace hicpAroll = 1 if ((qdate == 2 | qdate == 3 | qdate == 4) & year == `year' + 1 & month !=.)
   label var hicpAroll "Rolling 1 Yr ahead HICP Inflation Expectation"
   
   /* One Year- One Year Forward Rolling Horizon Dummy */
   gen hicpBroll = 0
   replace hicpBroll = 1 if (qdate == 1 & year == `year' + 1 & month != .)
   replace hicpBroll = 1 if ((qdate == 2 | qdate == 3 | qdate == 4) & year == `year' + 2 & month !=.)
   label var hicpBroll "Rolling 1YR-1YR forward HICP Inflation Expectation"
   
   /* Calendar Two Year Ahead Dummy */
   gen hicptwoyr = 0
   replace hicptwoyr = 1 if ((ydate > 1999 & (qdate == 3 | qdate == 4)) & year == `year' + 2 & month == .)
   label var hicptwoyr "Two Year ahead HICP Inflation Expectation"
   
   /* Calendar Five Year Ahead Dummy */
   gen hicpfiveyr = 0
   replace hicpfiveyr = 1 if ((qdate == 1 & ydate == 1999) & year == `year' + 4 & month == .)
   replace hicpfiveyr = 1 if ((qdate == 1 & ydate == 2000) & year == `year' + 4 & month == .)
   replace hicpfiveyr = 1 if ((ydate > 2000 & (qdate == 1 | qdate == 2)) & year == `year' + 4 & month == .)
   replace hicpfiveyr = 1 if ((ydate > 2000 & (qdate == 3 | qdate == 4)) & year == `year' + 5 & month == .)
   label var hicpfiveyr "Five Year ahead HICP Inflation Expectation"
   
   destring v*, replace

   /* Rename Variables by "bins" */
   /* Number of bins have changed across time. The loop changes how many "bins" are created*/
   if (`year' < 2000) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .     
      drop v*
   }
   else if (`year' ==  2000 & (`quarter' == 1 | `quarter' == 2 | `quarter' == 3)) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .     
      drop v*
   }
   else if (`year' == 2000 & `quarter' == 4) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      drop v*
   }
   else if (`year' > 2000 & `year' <2008){
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      drop v*
   }
   else if (`year' == 2008 & (`quarter' == 1 | `quarter' == 2)) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .         
      drop v*
   }
   else if (`year' == 2008 & (`quarter' == 3|`quarter' == 4)) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      drop v*
   }
   else if (`year' == 2009 & `quarter' == 1) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      drop v*
   }


   else if (`year' == 2009 & (`quarter' == 2 | `quarter' == 3 | `quarter' == 4)) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      rename v14 a11
      rename v15 a12
      rename v16 a13
      rename v17 a14
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      replace a11 = 0 if a11 == .
      replace a12 = 0 if a12 == .
      replace a13 = 0 if a13 == .
      replace a14 = 0 if a14 == .
      drop v*
   }
   else if (`year' > 2009) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      rename v14 a11
      rename v15 a12
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      replace a11 = 0 if a11 == .
      replace a12 = 0 if a12 == .
      drop v*      
   }

   foreach i of numlist 1(1)14 {
	capture replace a`i' = a`i'/100
   }
   
   destring person point, replace            
   preserve

   /* Create Dataset: Keep Current Year Ahead HICP Inflation Forecasts */
   drop if hicpA == 0
               
   if (`year' == $start_year & `quarter' == $start_quarter) {
      save "$data/hicpA.dta", replace
   }
   else {
      save "$data/temp.dta", replace
      append using "$data/hicpA.dta"
      save "$data/hicpA.dta", replace
   }

   restore

   preserve

   /* Create Dataset: Keep Next Year Ahead HICP Inflation Forecasts */
   drop if hicpB == 0
               
   if (`year' == $start_year & `quarter' == $start_quarter) {
      save "$data/hicpB.dta", replace
   }
   else {
      save "$data/temp.dta", replace
      append using "$data/hicpB.dta"
      save "$data/hicpB.dta", replace
   }

   restore
               
   preserve

   /* Create Dataset: Keep One Year Ahead HICP Inflation Forecast */
   drop if hicpAroll == 0
               
   if (`year' == $start_year & `quarter' == $start_quarter) {
      save "$data/hicpAroll.dta", replace
   }
   else {
      save "$data/temp.dta", replace
      append using "$data/hicpAroll.dta"
      save "$data/hicpAroll.dta", replace
   }

   restore
   preserve

   /* Create Dataset: Keep 1yr-1yr Forward HICP Inflation Forecast */
   drop if hicpBroll == 0
               
   if (`year' == $start_year & `quarter' == $start_quarter) {
      save "$data/hicpBroll.dta", replace
   }
   else {
      save "$data/temp.dta", replace
      append using "$data/hicpBroll.dta"
      save "$data/hicpBroll.dta", replace
   }

   restore
               
   preserve

   /* Create Dataset: Keep Two Year ahead HICP Inflation Forecast */
   drop if hicptwoyr == 0
               
   if (`year' == $start_year & `quarter' == $start_quarter) {
      save "$data/hicptwoyr.dta", replace
   }
   else {
      save "$data/temp.dta", replace 
      append using "$data/hicptwoyr.dta"
      save "$data/hicptwoyr.dta", replace
   }

   restore
               
   preserve

   /* Create Dataset: Keep Five Year ahead HICP Inflation Forecast */
   drop if hicpfiveyr == 0
               
   if (`year' == $start_year & `quarter' == $start_quarter) {
      save "$data/hicpfiveyr.dta", replace
   }
   else {
      save "$data/temp.dta", replace
      append using "$data/hicpfiveyr.dta"
      save "$data/hicpfiveyr.dta", replace
   }

   restore

   
/*****************************************************************************************/
/*****************************************************************************************/
/*****************************************************************************************/
   
   destring year, replace
   
   /*Change Date Here!!!!!!!! Should be the date of the most recent dataset*/
   if (`year' == $end_year & `quarter' == $end_quarter) {
      local z = 1
   }
   
   local quarter = `quarter' + 1

   if `quarter' == 5 {
      local year = `year' + 1
      local quarter = 1
   }
}



use "$data/hicpA.dta", clear
sort ydate qdate person
drop hicpA hicpB hicpAroll hicpBroll hicptwoyr hicpfiveyr

/* Generate Interval Groups */

capture confirm var group
if !_rc {
	disp "group defined"
}
else {
	disp "group not defined"
	gen group = 0
}

replace group = 1 if ydate == 1999 | (ydate == 2000 & qdate != 4) | (ydate >= 2001 & ydate < 2008) | (ydate == 2008 & (qdate == 1 | qdate == 2))
replace group = 2 if (ydate == 2000 & qdate == 4) | (ydate == 2008 & (qdate == 3 | qdate == 4)) | (ydate == 2009 & qdate == 1)
replace group = 3 if ydate == 2009 & (qdate == 2 | qdate == 3 | qdate == 4)
replace group = 4 if ydate >= 2010

save, replace

use "$data/hicpB.dta", clear
sort ydate qdate person
drop hicpA hicpB hicpAroll hicpBroll hicptwoyr hicpfiveyr


/* Generate Interval Groups */

capture confirm var group
if !_rc {
	disp "group defined"
}
else {
	disp "group not defined"
	gen group = 0
}

replace group = 1 if ydate == 1999 | (ydate == 2000 & qdate != 4) | (ydate >= 2001 & ydate < 2008) | (ydate == 2008 & (qdate == 1 | qdate == 2))
replace group = 2 if (ydate == 2000 & qdate == 4) | (ydate == 2008 & (qdate == 3 | qdate == 4)) | (ydate == 2009 & qdate == 1)
replace group = 3 if ydate == 2009 & (qdate == 2 | qdate == 3 | qdate == 4)
replace group = 4 if ydate >= 2010

save, replace

use "$data/hicpAroll.dta", clear
sort ydate qdate person
drop hicpA hicpB hicpAroll hicpBroll hicptwoyr hicpfiveyr


/* Generate Interval Groups */

capture confirm var group
if !_rc {
	disp "group defined"
}
else {
	disp "group not defined"
	gen group = 0
}

replace group = 1 if ydate == 1999 | (ydate == 2000 & qdate != 4) | (ydate >= 2001 & ydate < 2008) | (ydate == 2008 & (qdate == 1 | qdate == 2))
replace group = 2 if (ydate == 2000 & qdate == 4) | (ydate == 2008 & (qdate == 3 | qdate == 4)) | (ydate == 2009 & qdate == 1)
replace group = 3 if ydate == 2009 & (qdate == 2 | qdate == 3 | qdate == 4)
replace group = 4 if ydate >= 2010

save, replace

use "$data/hicpBroll.dta", clear
sort ydate qdate person
drop hicpA hicpB hicpAroll hicpBroll hicptwoyr hicpfiveyr


/* Generate Interval Groups */

capture confirm var group
if !_rc {
	disp "group defined"
}
else {
	disp "group not defined"
	gen group = 0
}

replace group = 1 if ydate == 1999 | (ydate == 2000 & qdate != 4) | (ydate >= 2001 & ydate < 2008) | (ydate == 2008 & (qdate == 1 | qdate == 2))
replace group = 2 if (ydate == 2000 & qdate == 4) | (ydate == 2008 & (qdate == 3 | qdate == 4)) | (ydate == 2009 & qdate == 1)
replace group = 3 if ydate == 2009 & (qdate == 2 | qdate == 3 | qdate == 4)
replace group = 4 if ydate >= 2010

save, replace

use "$data/hicptwoyr.dta", clear
sort ydate qdate person
drop hicpA hicpB hicpAroll hicpBroll hicptwoyr hicpfiveyr


/* Generate Interval Groups */

capture confirm var group
if !_rc {
	disp "group defined"
}
else {
	disp "group not defined"
	gen group = 0
}

replace group = 1 if ydate == 1999 | (ydate == 2000 & qdate != 4) | (ydate >= 2001 & ydate < 2008) | (ydate == 2008 & (qdate == 1 | qdate == 2))
replace group = 2 if (ydate == 2000 & qdate == 4) | (ydate == 2008 & (qdate == 3 | qdate == 4)) | (ydate == 2009 & qdate == 1)
replace group = 3 if ydate == 2009 & (qdate == 2 | qdate == 3 | qdate == 4)
replace group = 4 if ydate >= 2010

save, replace

use "$data/hicpfiveyr.dta", clear
sort ydate qdate person
drop hicpA hicpB hicpAroll hicpBroll hicptwoyr hicpfiveyr


/* Generate Interval Groups */

capture confirm var group
if !_rc {
	disp "group defined"
}
else {
	disp "group not defined"
	gen group = 0
}

replace group = 1 if ydate == 1999 | (ydate == 2000 & qdate != 4) | (ydate >= 2001 & ydate < 2008) | (ydate == 2008 & (qdate == 1 | qdate == 2))
replace group = 2 if (ydate == 2000 & qdate == 4) | (ydate == 2008 & (qdate == 3 | qdate == 4)) | (ydate == 2009 & qdate == 1)
replace group = 3 if ydate == 2009 & (qdate == 2 | qdate == 3 | qdate == 4)
replace group = 4 if ydate >= 2010

save, replace


   use "$data/temp_GDP_2000Q1.dta", clear

/*Parse & append the data by forecast horizons GDP */

local year = $start_year /*set year*/
local quarter = $start_quarter /*set quarter*/
local z = 0 /*set dummy*/

while `z' == 0 {
   
   use "$data/temp_GDP_`year'Q`quarter'.dta", clear

   /*************************************************/
   /* Create Dummies by Forecast Horizon            */
   /*************************************************/

   /*Current Calendar Year Horizon Dummy */
   gen gdpA = 0
   replace gdpA = 1 if (year == `year' & quarter == .)

   /* Next Calendar Year Horizon Dummy */
   gen gdpB = 0
   replace gdpB = 1 if (year == `year' + 1 & quarter == .)

   /* One Year Ahead Rolling Horizon Dummy */
   gen gdpAroll = 0
   replace gdpAroll = 1 if ((qdate == 1 | qdate == 2) & year == `year' & quarter != .)
   replace gdpAroll = 1 if ((qdate == 3 | qdate == 4) & year == `year' + 1 & quarter !=.)

   /* Two Year Ahead Rolling Horizon Dummy */
   gen gdpBroll = 0
   replace gdpBroll = 1 if ((qdate == 1 | qdate == 2) & year == `year' + 1  & quarter != .)
   replace gdpBroll = 1 if ((qdate == 3 | qdate == 4) & year == `year' + 2 & quarter !=.)

   /* Calendar Two Year Ahead Dummy */
   gen gdptwoyr = 0
   replace gdptwoyr = 1 if ((ydate > 1999 & (qdate == 3 | qdate == 4)) & year == `year' + 2 & quarter == .)

   /* Calendar Five Year Ahead Dummy */
   gen gdpfiveyr = 0
   replace gdpfiveyr = 1 if ((qdate == 1 & ydate == 1999) & year == `year' + 4 & quarter == .)
   replace gdpfiveyr = 1 if ((qdate == 1 & ydate == 2000) & year == `year' + 4 & quarter == .)
   replace gdpfiveyr = 1 if ((ydate > 2000 & (qdate == 1 | qdate == 2)) & year == `year' + 4 & quarter == .)
   replace gdpfiveyr = 1 if ((ydate > 2000 & (qdate == 3 | qdate == 4)) & year == `year' + 5 & quarter == .)

   if (`year' < 2000) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      capture drop v*
   }
   else if (`year' ==  2000 & (`quarter' == 1)) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      capture drop v*
   }
   else if (`year' == 2000 & (`quarter' == 2 | `quarter' == 3 | `quarter' == 4)) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      rename v14 a11
      rename v15 a12
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      replace a11 = 0 if a11 == .
      replace a12 = 0 if a12 == .
      capture drop v*
   }
   else if (`year' > 2000 & `year' <2008){
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      capture drop v*
   }
   else if (`year' == 2008 & (`quarter' == 1 | `quarter' == 2 | `quarter' == 3)) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10 
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      capture drop v*
   }
   else if (`year' == 2008 & (`quarter' == 4)) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      rename v14 a11
      rename v15 a12
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      replace a11 = 0 if a11 == .
      replace a12 = 0 if a12 == .
      capture drop v*
   }
   else if (`year' == 2009 & `quarter' == 1) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      rename v14 a11
      rename v15 a12
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      replace a11 = 0 if a11 == .
      replace a12 = 0 if a12 == .
      capture drop v*
   }


   else if (`year' == 2009 & (`quarter' == 2 | `quarter' == 3 | `quarter' == 4)) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      rename v14 a11
      rename v15 a12
      rename v16 a13
      rename v17 a14
      rename v18 a15
      rename v19 a16
      rename v20 a17
      rename v21 a18
      rename v22 a19
      rename v23 a20
      rename v24 a21
      rename v25 a22
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      replace a11 = 0 if a11 == .
      replace a12 = 0 if a12 == .
      replace a13 = 0 if a13 == .
      replace a14 = 0 if a14 == .
      replace a15 = 0 if a15 == .
      replace a16 = 0 if a16 == .
      replace a17 = 0 if a17 == .
      replace a18 = 0 if a18 == .
      replace a19 = 0 if a19 == .
      replace a20 = 0 if a20 == .
      replace a21 = 0 if a21 == .
      replace a22 = 0 if a22 == .
      capture drop v*
   }
   else if (`year' > 2009) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      rename v14 a11
      rename v15 a12
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      replace a11 = 0 if a11 == .
      replace a12 = 0 if a12 == .
      capture drop v*      
   }
   
   foreach i of numlist 1(1)22 {
	capture replace a`i' = a`i'/100
   }     
          
   preserve

   /* Create Dataset: Keep Current Year GDP forecast */
   drop if gdpA == 0
               
   if (`year' == $start_year & `quarter' == $start_quarter) {
      save "$data/gdpA.dta", replace
   }
   else {
      save "$data/temp.dta", replace
      append using "$data/gdpA.dta"
      save "$data/gdpA.dta", replace
   }

   restore

   preserve

   /* Create Dataset: Keep Next Year GDP forecast */
   drop if gdpB == 0
               
   if (`year' == $start_year & `quarter' == $start_quarter) {
      save "$data/gdpB.dta", replace
   }
   else {
      save "$data/temp.dta", replace
      append using "$data/gdpB.dta"
      save "$data/gdpB.dta", replace
   }

   restore
               
   preserve

   /* Create Dataset: Keep One Year Ahead Rolling GDP forecast */
   drop if gdpAroll == 0
               
   if (`year' == $start_year & `quarter' == $start_quarter) {
      save "$data/gdpAroll.dta", replace
   }
   else {
      save "$data/temp.dta", replace
      append using "$data/gdpAroll.dta"
      save "$data/gdpAroll.dta", replace
   }

   restore
   preserve

   /* Create Dataset: Keep 1yr-1yr Forward Rolling GDP forecast */
   
   drop if gdpBroll == 0
               
   if (`year' == $start_year & `quarter' == $start_quarter) {
      save "$data/gdpBroll.dta", replace
   }
   else {
      save "$data/temp.dta", replace
      append using "$data/gdpBroll.dta"
      save "$data/gdpBroll.dta", replace
   }

   restore
               
   preserve

   /* Create Dataset: Keep Two year ahead GDP forecast */
   drop if gdptwoyr == 0
               
   if (`year' == $start_year & `quarter' == $start_quarter) {
      save "$data/gdptwoyr.dta", replace
   }
   else {
      save "$data/temp.dta", replace 
      append using "$data/gdptwoyr.dta"
      save "$data/gdptwoyr.dta", replace
   }

   restore
               
   preserve

   /* Create Dataset: Keep Five year ahead GDP forecast */
   drop if gdpfiveyr == 0
               
   if (`year' == $start_year & `quarter' == $start_quarter) {
      save "$data/gdpfiveyr.dta", replace
   }
   else {
      save "$data/temp.dta", replace
      append using  "$data/gdpfiveyr.dta"
      save "$data/gdpfiveyr.dta", replace
   }

   restore
   
   /*Change Date Here!!!!!!!! Should be the date of the most recent dataset*/
   if (`year' == $end_year & `quarter' == $end_quarter) {
      local z = 1
   }
   
   local quarter = `quarter' + 1

   if `quarter' == 5 {
      local year = `year' + 1
      local quarter = 1
   }
}


/* Clean Final Data Set */

use "$data/gdpA.dta", clear

capture confirm var group
if !_rc {
	disp "group defined"
}
else {
	disp "mdate not defined"
	gen group = 0
}

replace group = 1 if ydate == 1999 | ydate == 2000 & qdate == 1| (ydate >= 2001 & ydate < 2008) | (ydate == 2008 & (qdate == 1 | qdate == 2 | qdate == 3))
replace group = 2 if ydate == 2000 & (qdate == 2 | qdate == 3 | qdate == 4)
replace group = 3 if (ydate == 2008 & qdate == 4) | (ydate == 2009 & qdate == 1) |ydate >= 2010
replace group = 4 if ydate == 2009 & (qdate == 2 | qdate == 3 | qdate == 4)


sort ydate qdate person
drop gdpA gdpB gdpAroll gdpBroll gdptwoyr gdpfiveyr

save, replace

use "$data/gdpB.dta", clear

capture confirm var group
if !_rc {
	disp "group defined"
}
else {
	disp "mdate not defined"
	gen group = 0
}

replace group = 1 if ydate == 1999 | ydate == 2000 & qdate == 1| (ydate >= 2001 & ydate < 2008) | (ydate == 2008 & (qdate == 1 | qdate == 2 | qdate == 3))
replace group = 2 if ydate == 2000 & (qdate == 2 | qdate == 3 | qdate == 4)
replace group = 3 if (ydate == 2008 & qdate == 4) | (ydate == 2009 & qdate == 1) |ydate >= 2010
replace group = 4 if ydate == 2009 & (qdate == 2 | qdate == 3 | qdate == 4)


sort ydate qdate person
drop gdpA gdpB gdpAroll gdpBroll gdptwoyr gdpfiveyr
save, replace

use "$data/gdpAroll.dta", clear


capture confirm var group
if !_rc {
	disp "group defined"
}
else {
	disp "mdate not defined"
	gen group = 0
}

replace group = 1 if ydate == 1999 | ydate == 2000 & qdate == 1| (ydate >= 2001 & ydate < 2008) | (ydate == 2008 & (qdate == 1 | qdate == 2 | qdate == 3))
replace group = 2 if ydate == 2000 & (qdate == 2 | qdate == 3 | qdate == 4)
replace group = 3 if (ydate == 2008 & qdate == 4) | (ydate == 2009 & qdate == 1) |ydate >= 2010
replace group = 4 if ydate == 2009 & (qdate == 2 | qdate == 3 | qdate == 4)


sort ydate qdate person
drop gdpA gdpB gdpAroll gdpBroll gdptwoyr gdpfiveyr
save, replace

use "$data/gdpBroll.dta", clear


capture confirm var group
if !_rc {
	disp "group defined"
}
else {
	disp "mdate not defined"
	gen group = 0
}

replace group = 1 if ydate == 1999 | ydate == 2000 & qdate == 1| (ydate >= 2001 & ydate < 2008) | (ydate == 2008 & (qdate == 1 | qdate == 2 | qdate == 3))
replace group = 2 if ydate == 2000 & (qdate == 2 | qdate == 3 | qdate == 4)
replace group = 3 if (ydate == 2008 & qdate == 4) | (ydate == 2009 & qdate == 1) |ydate >= 2010
replace group = 4 if ydate == 2009 & (qdate == 2 | qdate == 3 | qdate == 4)


sort ydate qdate person
drop gdpA gdpB gdpAroll gdpBroll gdptwoyr gdpfiveyr
save, replace

use "$data/gdptwoyr.dta", clear


capture confirm var group
if !_rc {
	disp "group defined"
}
else {
	disp "mdate not defined"
	gen group = 0
}

replace group = 1 if ydate == 1999 | ydate == 2000 & qdate == 1| (ydate >= 2001 & ydate < 2008) | (ydate == 2008 & (qdate == 1 | qdate == 2 | qdate == 3))
replace group = 2 if ydate == 2000 & (qdate == 2 | qdate == 3 | qdate == 4)
replace group = 3 if (ydate == 2008 & qdate == 4) | (ydate == 2009 & qdate == 1) |ydate >= 2010
replace group = 4 if ydate == 2009 & (qdate == 2 | qdate == 3 | qdate == 4)


sort ydate qdate person
drop gdpA gdpB gdpAroll gdpBroll gdptwoyr gdpfiveyr
save, replace

use "$data/gdpfiveyr.dta", clear


capture confirm var group
if !_rc {
	disp "group defined"
}
else {
	disp "mdate not defined"
	gen group = 0
}

replace group = 1 if ydate == 1999 | ydate == 2000 & qdate == 1| (ydate >= 2001 & ydate < 2008) | (ydate == 2008 & (qdate == 1 | qdate == 2 | qdate == 3))
replace group = 2 if ydate == 2000 & (qdate == 2 | qdate == 3 | qdate == 4)
replace group = 3 if (ydate == 2008 & qdate == 4) | (ydate == 2009 & qdate == 1) |ydate >= 2010
replace group = 4 if ydate == 2009 & (qdate == 2 | qdate == 3 | qdate == 4)

sort ydate qdate person
drop gdpA gdpB gdpAroll gdpBroll gdptwoyr gdpfiveyr
save, replace
*/

*	++++++++++++	*
*	UNEMPLOYMENT	*
*	++++++++++++	*

/*Parse & append the data by forecast horizons */

local year = $start_year /*set year*/
local quarter = $start_quarter /*set quarter*/
local z = 0 /*set dummy*/

while `z' == 0 {
   
   use "$data/temp_unemployment_`year'Q`quarter'.dta", clear

   /********************************************************************/
   /* Create Dummies by forecast horizons                              */
   /********************************************************************/
   
   /*Current Calendar Year Horizon Dummy */
   gen urateA = 0
   replace urateA = 1 if (year == `year' & month == .)
   label var urateA "Current Year Unemployment Expectation"
   
   /* Next Calendar Year Horizon Dummy */
   gen urateB = 0
   replace urateB = 1 if (year == `year' + 1 & month == .)
   label var urateB "Next Year Unemployment Expectation"
   
   /* One Year Ahead Rolling Horizon Dummy */
   gen urateAroll = 0
   replace urateAroll = 1 if (qdate == 1 & year == `year' & month != .)
   replace urateAroll = 1 if ((qdate == 2 | qdate == 3 | qdate == 4) & year == `year' + 1 & month !=.)
   label var urateAroll "Rolling 1 Yr ahead Unemployment Expectation"
   
   /* One Year- One Year Forward Rolling Horizon Dummy */
   gen urateBroll = 0
   replace urateBroll = 1 if (qdate == 1 & year == `year' + 1 & month != .)
   replace urateBroll = 1 if ((qdate == 2 | qdate == 3 | qdate == 4) & year == `year' + 2 & month !=.)
   label var urateBroll "Rolling 1YR-1YR forward Unemployment Expectation"
   
   /* Calendar Two Year Ahead Dummy */
   gen uratetwoyr = 0
   replace uratetwoyr = 1 if ((ydate > 1999 & (qdate == 3 | qdate == 4)) & year == `year' + 2 & month == .)
   label var uratetwoyr "Two Year ahead Unemployment Expectation"
   
   /* Calendar Five Year Ahead Dummy */
   gen uratefiveyr = 0
   replace uratefiveyr = 1 if ((qdate == 1 & ydate == 1999) & year == `year' + 4 & month == .)
   replace uratefiveyr = 1 if ((qdate == 1 & ydate == 2000) & year == `year' + 4 & month == .)
   replace uratefiveyr = 1 if ((ydate > 2000 & (qdate == 1 | qdate == 2)) & year == `year' + 4 & month == .)
   replace uratefiveyr = 1 if ((ydate > 2000 & (qdate == 3 | qdate == 4)) & year == `year' + 5 & month == .)
   label var uratefiveyr "Five Year ahead Unemployment Expectation"

   /* Rename Variables by "bins" */
   /* Number of bins have changed across time. The loop changes how many "bins" are created*/
   if (`year' == 1999) | (`year' == 2000 & `quarter' == 1) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      capture drop v*
   }
   else if (`year' == 2000 & `quarter' == 2){
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      rename v14 a11
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      replace a11 = 0 if a11 == .
      capture drop v*
   }  
   else if (`year' ==  2000 & (`quarter' == 3 | `quarter' == 4)) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      rename v14 a11
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      replace a11 = 0 if a11 == .
      capture drop v*
   }
   else if (`year' == 2001 | (`year' == 2002 & `quarter' == 1)) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      rename v14 a11
      rename v15 a12
      rename v16 a13
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      replace a11 = 0 if a11 == .
      replace a12 = 0 if a12 == .
      replace a13 = 0 if a13 == .
      capture drop v*
   }
   else if ((`year' ==  2002 & `quarter' != 1) | (`year' >= 2003 & `year' <= 2008) | (`year' == 2009 & `quarter' == 1)){
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      rename v14 a11
      rename v15 a12
      rename v16 a13
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      replace a11 = 0 if a11 == .
      replace a12 = 0 if a12 == .
      replace a13 = 0 if a13 == .
      capture drop v*
   }
   else if (`year' == 2009 & (`quarter' == 2 | `quarter' == 3 | `quarter' == 4)) {
      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      rename v14 a11
      rename v15 a12
      rename v16 a13
      rename v17 a14
      rename v18 a15
      rename v19 a16
      rename v20 a17
      rename v21 a18
      rename v22 a19
      rename v23 a20
      rename v24 a21
      
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .         
      replace a10 = 0 if a10 == .         
      replace a11 = 0 if a11 == .         
      replace a12 = 0 if a12 == .         
      replace a13 = 0 if a13 == .         
      replace a14 = 0 if a14 == .         
      replace a15 = 0 if a15 == .         
      replace a16 = 0 if a16 == .         
      replace a17 = 0 if a17 == .         
      replace a18= 0 if a18 == .         
      replace a19 = 0 if a19 == .         
      replace a20 = 0 if a20 == .         
      replace a21 = 0 if a21 == .         

      capture drop v*
   }
   else if (`year' >= 2010) {

      rename v4 a1
      rename v5 a2
      rename v6 a3
      rename v7 a4
      rename v8 a5
      rename v9 a6
      rename v10 a7
      rename v11 a8
      rename v12 a9
      rename v13 a10
      rename v14 a11
      rename v15 a12
      rename v16 a13
      rename v17 a14
      rename v18 a15
      rename v19 a16
      rename v20 a17
      rename v21 a18
      rename v22 a19
      replace a1 = 0 if a1 == .
      replace a2 = 0 if a2 == .
      replace a3 = 0 if a3 == .
      replace a4 = 0 if a4 == .
      replace a5 = 0 if a5 == .
      replace a6 = 0 if a6 == .
      replace a7 = 0 if a7 == .
      replace a8 = 0 if a8 == .
      replace a9 = 0 if a9 == .
      replace a10 = 0 if a10 == .
      replace a11 = 0 if a11 == .
      replace a12 = 0 if a12 == .
      replace a13 = 0 if a13 == .
      replace a14 = 0 if a14 == .
      replace a15 = 0 if a15 == .
      replace a16 = 0 if a16 == .
      replace a17 = 0 if a17 == .
      replace a18 = 0 if a18 == .
      replace a19 = 0 if a19 == .
      capture drop v*
   }

   foreach i of numlist 1(1)19 {
	capture replace a`i' = a`i'/100
   }
               
   preserve

   /* Create Dataset: Keep Current Year Ahead Unemployment Forecasts */
   drop if urateA == 0
               
   if (`year' == 1999 & `quarter' == 1) {
      save "$data/urateA.dta", replace
   }
   else {
      save "$data/temp.dta", replace
      append using "$data/urateA.dta"
      save "$data/urateA.dta", replace
   }

   restore

   preserve

   /* Create Dataset: Keep Next Year Ahead Unemployment Forecasts */
   drop if urateB == 0
               
   if (`year' == 1999 & `quarter' == 1) {
      save "$data/urateB.dta", replace
   }
   else {
      save "$data/temp.dta", replace
      append using "$data/urateB.dta"
      save "$data/urateB.dta", replace
   }

   restore
               
   preserve

   /* Create Dataset: Keep One Year Ahead Unemployment Forecast */
   drop if urateAroll == 0
               
   if (`year' == 1999 & `quarter' == 1) {
      save "$data/urateAroll.dta", replace
   }
   else {
      save "$data/temp.dta", replace
      append using "$data/urateAroll.dta"
      save "$data/urateAroll.dta", replace
   }

   restore
   preserve

   /* Create Dataset: Keep 1yr-1yr Forward Unemployment Forecast */
   drop if urateBroll == 0
               
   if (`year' == 1999 & `quarter' == 1) {
      save "$data/urateBroll.dta", replace
   }
   else {
      save "$data/temp.dta", replace
      append using "$data/urateBroll.dta"
      save "$data/urateBroll.dta", replace
   }

   restore
               
   preserve

   /* Create Dataset: Keep Two Year ahead Unemployment Forecast */
   drop if uratetwoyr == 0
               
   if (`year' == 1999 & `quarter' == 1) {
      save "$data/uratetwoyr.dta", replace
   }
   else {
      save "$data/temp.dta", replace 
      append using "$data/uratetwoyr.dta"
      save "$data/uratetwoyr.dta", replace
   }

   restore
               
   preserve

   /* Create Dataset: Keep Five Year ahead Unemployment Forecast */
   drop if uratefiveyr == 0
               
   if (`year' == 1999 & `quarter' == 1) {
      save "$data/uratefiveyr.dta", replace
   }
   else {
      save "$data/temp.dta", replace
      append using  "$data/uratefiveyr.dta"
      save "$data/uratefiveyr.dta", replace
   }

   restore

   
/*****************************************************************************************/
/*****************************************************************************************/
/*****************************************************************************************/
   
   
   
   /*Change Date Here!!!!!!!! Should be the date of the most recent dataset*/
   if (`year' == $end_year & `quarter' == $end_quarter) {
      local z = 1
   }
   
   local quarter = `quarter' + 1

   if `quarter' == 5 {
      local year = `year' + 1
      local quarter = 1
   }
}

use "$data/urateA.dta", clear
sort ydate qdate person
drop urateA urateB urateAroll urateBroll uratetwoyr uratefiveyr

/* Generate Interval Groups */

capture confirm var group
if !_rc {
	disp "group defined"
}
else {
	disp "group not defined"
	gen group = 0
}

replace group = 1 if ydate == 1999 | (ydate == 2000 & qdate == 1)
replace group = 2 if ydate == 2000 & qdate == 2
replace group = 3 if ydate == 2000 & (qdate == 3 | qdate == 4)
replace group = 4 if ydate == 2001 | (ydate == 2002 & qdate == 1)
replace group = 5 if (ydate == 2002 & qdate != 1) | (ydate >=2003 & ydate <=2008) | (ydate == 2009 & qdate == 1) 
replace group = 6 if ydate == 2009 & qdate != 1
replace group = 7 if ydate >= 2010

save, replace

use "$data/urateB.dta", clear
sort ydate qdate person
drop urateA urateB urateAroll urateBroll uratetwoyr uratefiveyr


/* Generate Interval Groups */

capture confirm var group
if !_rc {
	disp "group defined"
}
else {
	disp "group not defined"
	gen group = 0
}

replace group = 1 if ydate == 1999 | (ydate == 2000 & qdate == 1)
replace group = 2 if ydate == 2000 & qdate == 2
replace group = 3 if ydate == 2000 & (qdate == 3 | qdate == 4)
replace group = 4 if ydate == 2001 | (ydate == 2002 & qdate == 1)
replace group = 5 if (ydate == 2002 & qdate != 1) | (ydate >=2003 & ydate <=2008) | (ydate == 2009 & qdate == 1) 
replace group = 6 if ydate == 2009 & qdate != 1
replace group = 7 if ydate >= 2010


save, replace

use "$data/urateAroll.dta", clear
sort ydate qdate person
drop urateA urateB urateAroll urateBroll uratetwoyr uratefiveyr


/* Generate Interval Groups */

capture confirm var group
if !_rc {
	disp "group defined"
}
else {
	disp "group not defined"
	gen group = 0
}

replace group = 1 if ydate == 1999 | (ydate == 2000 & qdate == 1)
replace group = 2 if ydate == 2000 & qdate == 2
replace group = 3 if ydate == 2000 & (qdate == 3 | qdate == 4)
replace group = 4 if ydate == 2001 | (ydate == 2002 & qdate == 1)
replace group = 5 if (ydate == 2002 & qdate != 1) | (ydate >=2003 & ydate <=2008) | (ydate == 2009 & qdate == 1) 
replace group = 6 if ydate == 2009 & qdate != 1
replace group = 7 if ydate >= 2010

save, replace

use "$data/urateBroll.dta", clear
sort ydate qdate person
drop urateA urateB urateAroll urateBroll uratetwoyr uratefiveyr


/* Generate Interval Groups */

capture confirm var group
if !_rc {
	disp "group defined"
}
else {
	disp "mdate not defined"
	gen group = 0
}

replace group = 1 if ydate == 1999 | (ydate == 2000 & qdate == 1)
replace group = 2 if ydate == 2000 & qdate == 2
replace group = 3 if ydate == 2000 & (qdate == 3 | qdate == 4)
replace group = 4 if ydate == 2001 | (ydate == 2002 & qdate == 1)
replace group = 5 if (ydate == 2002 & qdate != 1) | (ydate >=2003 & ydate <=2008) | (ydate == 2009 & qdate == 1) 
replace group = 6 if ydate == 2009 & qdate != 1
replace group = 7 if ydate >= 2010

save, replace

use "$data/uratetwoyr.dta", clear
sort ydate qdate person
drop urateA urateB urateAroll urateBroll uratetwoyr uratefiveyr


/* Generate Interval Groups */

capture confirm var group
if !_rc {
	disp "group defined"
}
else {
	disp "group not defined"
	gen group = 0
}

replace group = 1 if ydate == 1999 | (ydate == 2000 & qdate == 1)
replace group = 2 if ydate == 2000 & qdate == 2
replace group = 3 if ydate == 2000 & (qdate == 3 | qdate == 4)
replace group = 4 if ydate == 2001 | (ydate == 2002 & qdate == 1)
replace group = 5 if (ydate == 2002 & qdate != 1) | (ydate >=2003 & ydate <=2008) | (ydate == 2009 & qdate == 1) 
replace group = 6 if ydate == 2009 & qdate != 1
replace group = 7 if ydate >= 2010


save, replace

use "$data/uratefiveyr.dta", clear
sort ydate qdate person
drop urateA urateB urateAroll urateBroll uratetwoyr uratefiveyr


/* Generate Interval Groups */

capture confirm var group
if !_rc {
	disp "group defined"
}
else {
	disp "group not defined"
	gen group = 0
}

replace group = 1 if ydate == 1999 | (ydate == 2000 & qdate == 1)
replace group = 2 if ydate == 2000 & qdate == 2
replace group = 3 if ydate == 2000 & (qdate == 3 | qdate == 4)
replace group = 4 if ydate == 2001 | (ydate == 2002 & qdate == 1)
replace group = 5 if (ydate == 2002 & qdate != 1) | (ydate >=2003 & ydate <=2008) | (ydate == 2009 & qdate == 1) 
replace group = 6 if ydate == 2009 & qdate != 1
replace group = 7 if ydate >= 2010

save, replace


/* Erase Temp Files */

local year = $start_year /* set starting year */
local quarter = $start_quarter /* set starting quarter */
local z = 0 /*set dummy to trigger to get out of loop */

while `z' == 0 {

   erase "$data/temp_GDP_`year'Q`quarter'.dta"
   erase "$data/temp_inflation_`year'Q`quarter'.dta"
   erase "$data/temp_unemployment_`year'Q`quarter'.dta"

   /*Change Date Here!!!!!!!! Should be the date of the most recent dataset*/
   if (`year' == $end_year & `quarter' == $end_quarter) {
      local z = 1
   }
   
   local quarter = `quarter' + 1

   if `quarter' == 5 {
      local year = `year' + 1
      local quarter = 1
   }
}

erase "$data/temp.dta"

*log close

cd $main
