/************************************************************************
   Tail_Bin_Count_Urate.do
   10/26/10 - Joseph Song
   2/3/14 - Kaivan K. Sattar

   Description: Create percentile by individual forecast distribution

   *********************************************************************/
set more off
clear

local data "A B 5"
foreach sampcut in 5 10 15 20 25 100 {
foreach x of local data {
   use output/urate/laxurate_Percentile`x'_`sampcut'.dta, clear
   global p = "`x'"

   gen count = 1
   bysort ydate qdate: egen MinBin = sum(count) if Bin1 == 1
   bysort ydate qdate: egen LowBin = sum(count) if Bin20 == 1
   bysort ydate qdate: egen HighBin1 = count(count) if group == 1 & Bin80 == 8
   bysort ydate qdate: egen HighBin2 = count(count) if group == 2 & Bin80 == 11
   bysort ydate qdate: egen HighBin3 = count(count) if group == 3 & Bin80 == 11
   bysort ydate qdate: egen HighBin4 = count(count) if group == 4 & Bin80 == 13
   bysort ydate qdate: egen HighBin5 = count(count) if group == 5 & Bin80 == 13
   bysort ydate qdate: egen HighBin6 = count(count) if group == 6 & Bin80 == 21
   bysort ydate qdate: egen HighBin7 = count(count) if group == 7 & Bin80 == 19

   forvalues x = 1/7 {
	replace HighBin`x' = 0 if HighBin`x' == .
   }
   
   gen HighBin = HighBin1 + HighBin2 + HighBin3 + HighBin4 + HighBin5 + HighBin6 + HighBin7
   drop HighBin1 HighBin2 HighBin3 HighBin4 HighBin5 HighBin6 HighBin7
   replace HighBin = . if HighBin == 0

   bysort ydate qdate: egen MaxBin1 = count(count) if group == 1 & Bin99 == 8
   bysort ydate qdate: egen MaxBin2 = count(count) if group == 2 & Bin99 == 11
   bysort ydate qdate: egen MaxBin3 = count(count) if group == 3 & Bin99 == 11
   bysort ydate qdate: egen MaxBin4 = count(count) if group == 4 & Bin99 == 13
   bysort ydate qdate: egen MaxBin5 = count(count) if group == 5 & Bin99 == 13
   bysort ydate qdate: egen MaxBin6 = count(count) if group == 6 & Bin99 == 21
   bysort ydate qdate: egen MaxBin7 = count(count) if group == 7 & Bin99 == 19

   forvalues x = 1/7 {
	replace MaxBin`x' = 0 if MaxBin`x' == .
   }

   gen MaxBin = MaxBin1 + MaxBin2 + MaxBin3 + MaxBin4 + MaxBin5 + MaxBin6 + MaxBin7
   drop MaxBin1 MaxBin2 MaxBin3 MaxBin4 MaxBin5 MaxBin6 MaxBin7
   replace MaxBin = . if MaxBin == 0
   
   gen iqr = abs(P75-P25)
   bysort ydate qdate: egen iqr_mean = mean(iqr)
   bysort ydate qdate: egen iqr_uncertainty_med = median(iqr)
   bysort ydate qdate: egen iqr_uncertainty_25 = pctile(iqr), p(25)
   bysort ydate qdate: egen iqr_uncertainty_75 = pctile(iqr), p(75)
   bysort ydate qdate: egen iqr_uncertainty_50 = pctile(iqr), p(50)
   bysort ydate qdate: egen iqr_uncertainty_10 = pctile(iqr), p(10)
   bysort ydate qdate: egen iqr_uncertainty_90 = pctile(iqr), p(90)
   bysort ydate qdate: egen iqr_disagreement = iqr(point)

   //collapse iqr_uncertainty iqr_disagreement, by(ydate qdate)
   collapse iqr_mean iqr_uncertainty_med iqr_uncertainty_25 iqr_uncertainty_75 iqr_uncertainty_50 iqr_uncertainty_90 iqr_uncertainty_10 iqr_disagreement HighBin LowBin MaxBin MinBin, by(ydate qdate)
   local x = "$p"
   replace HighBin = 0 if HighBin == .
   replace LowBin = 0 if LowBin == .
   replace MaxBin = 0 if MaxBin == .
   replace MinBin = 0 if MinBin == .
   outsheet using output/urate/laxurate_Percentile`x'_iqr_`sampcut'.csv, comma replace
}
}
