/************************************************************************
   Unc_Fore_Regressions.do
   3/27/14
  Hannah Herman

   Performs uncertainty-point prediction regressions

   *********************************************************************/
clear all
set more off
 
adopath + ado

*******************Full Sample************************
*GDP regressions 
	import excel using output/results/gdp_full_100.xlsx, clear
	local i = 1
	foreach var of varlist * {
		rename `var' v`i'
		local i = `i' + 1
	}
	destring *, replace
	drop if v1 == 2014
	
	*set 2009Q1 to missing for V28 v18 v33
	//replace v28 = . if v1 == 2009 & v2 == 1 
	replace v18 = . if v1 == 2009 & v2 == 1 
	replace v29 = . if v1 == 2009 & v2 == 1 

	matrix define Independent = (9,8,12,11,15,14)
	matrix define Dependent = (18,29,21,30,24,31)
	matrix define Lags = (2,3,4,4,3,4)
	
	forvalues i=1/6 {

	preserve
	
		local Ind = Independent[1,`i']
		disp `Ind'
		local Dep = Dependent[1,`i']
		dis `Dep'
		local lag = Lags[1,`i']
		disp `lag'
		
			*drop missing values 
			drop if v`Ind' == . 
			drop if v`Dep' ==.
			*generate time variable
			egen t = group(v1 v2)
			tsset t

			reg v`Dep' v`Ind'
			local a_r2 = e(r2_a)
			newey v`Dep' v`Ind', lag(`lag')
			test v`Ind'=0
			local tstat = invttail(e(df_r),r(p)/2)
			
			if `i'==1 {
				outreg2 using output/regressions/GDP_Regs_Unc_Fore, excel nor2 ///
					addstat(Adj R^2, `a_r2', Lags, `lag', Tstat, `tstat') ctitle("v`Dep'")  replace
			} 
			else {
				outreg2 using output/regressions/GDP_Regs_Unc_Fore, excel nor2 ///
					addstat(Adj R^2, `a_r2', Lags, `lag', Tstat, `tstat') ctitle("v`Dep'")  append 
			}
			*/
			restore

	}
	
*Hicp Regressions 
	import excel using output/results/hicp_full_100.xlsx, clear
	local i = 1
	foreach var of varlist * {
		rename `var' v`i'
		local i = `i' + 1
	}
	destring *, replace
	drop if v1 == 2014
	 
	
	*set 2003Q2 to missing for V29
	//replace v29 = . if v1 == 2003 & v2 == 2 

	matrix define Independent = (9,8,12,11,15,14)
	matrix define Dependent = (18,29,21,30,24,31)
	matrix define Lags = (6,6,6,6,4,2)
	
	forvalues i=1/6 {
		preserve

		local Ind = Independent[1,`i']
		disp `Ind'
		local Dep = Dependent[1,`i']
		dis `Dep'
		local lag = Lags[1,`i']
		disp `lag'
		
			*drop missing values 
			drop if v`Ind' == . 
			drop if v`Dep' ==.
			*generate time variable
			egen t = group(v1 v2)
			tsset t

			reg v`Dep' v`Ind'
			local a_r2 = e(r2_a)
			newey v`Dep' v`Ind', lag(`lag')
			test v`Ind'=0
			local tstat = invttail(e(df_r),r(p)/2)
		
			if `i'==1 {
				outreg2 using output/regressions/Hicp_Regs_Unc_Fore, excel nor2 ///
					addstat(Adj R^2, `a_r2', Lags, `lag', Tstat, `tstat') ctitle("v`Dep'") replace
			} 
			else {
				outreg2 using output/regressions/Hicp_Regs_Unc_Fore,  excel nor2 ///
					addstat(Adj R^2, `a_r2', Lags, `lag', Tstat, `tstat') ctitle("v`Dep'") append 
			}

		restore
	}
*/
*Urate Regressions 
	import excel using output/results/urate_full_100.xlsx, clear
	local i = 1
	foreach var of varlist * {
		rename `var' v`i'
		local i = `i' + 1
	}
	destring *, replace
	drop if v1 == 2014
	 
	
	matrix define Independent = (9,8,12,11,15,14)
	matrix define Dependent = (18,29,21,30,24,31)
	matrix define Lags = (8,10,6,9,0,1)
	
	forvalues i=1/6 {
		preserve

		local Ind = Independent[1,`i']
		disp `Ind'
		local Dep = Dependent[1,`i']
		dis `Dep'
		local lag = Lags[1,`i']
		disp `lag'
		
			*drop missing values 
			drop if v`Ind' == . 
			drop if v`Dep' ==.
			*generate time variable
			egen t = group(v1 v2)
			tsset t

			reg v`Dep' v`Ind'
			local a_r2 = e(r2_a)
			newey v`Dep' v`Ind', lag(`lag')
			test v`Ind'=0
			local tstat = invttail(e(df_r),r(p)/2)

			if `i'==1 {
				outreg2 using output/regressions/Urate_Regs_Unc_Fore, excel nor2 ///
					addstat(Adj R^2, `a_r2', Lags, `lag', Tstat, `tstat') ctitle("v`Dep'") replace
			} 
			else {
				outreg2 using output/regressions/Urate_Regs_Unc_Fore, excel nor2 ///
					addstat(Adj R^2, `a_r2', Lags, `lag', Tstat, `tstat') ctitle("v`Dep'") append
			}

		restore
	}

*********************Truncated Sample*****************************
*GDP regressions 
	import excel using output/results/gdp_full_100.xlsx, clear
	local i = 1
	foreach var of varlist * {
		rename `var' v`i'
		local i = `i' + 1
	}
	destring *, replace
	drop if v1 == 2014

	*Truncate data 1991Q1 - 2007Q2
	drop if v1 > 2007
	drop if v1 == 2007 & v2 >2	
	
	*set 2009Q1 to missing for V28 v18 v33
	//replace v28 = . if v1 == 2009 & v2 == 1 
	replace v18 = . if v1 == 2009 & v2 == 1 
	replace v29 = . if v1 == 2009 & v2 == 1 

	matrix define Independent = (9,8,12,11,15,14)
	matrix define Dependent = (18,29,21,30,24,31)
	matrix define Lags = (1,1,2,2,1,1)
	

	forvalues i=1/6 {
		preserve

		local Ind = Independent[1,`i']
		disp `Ind'
		local Dep = Dependent[1,`i']
		dis `Dep'
		local lag = Lags[1,`i']
		disp `lag'
		
			*drop missing values 
			drop if v`Ind' == . 
			drop if v`Dep' ==.
			*generate time variable
			egen t = group(v1 v2)
			tsset t

			reg v`Dep' v`Ind'
			local a_r2 = e(r2_a)
			newey v`Dep' v`Ind', lag(`lag')
			test v`Ind'=0
			local tstat = invttail(e(df_r),r(p)/2)

			if `i'==1 {
				outreg2 using output/regressions/Truncated_GDP_Regs_Unc_Fore, excel nor2 ///
					addstat(Adj R^2, `a_r2', Lags, `lag', Tstat, `tstat') ctitle("v`Dep'") replace
			} 
			else {
				outreg2 using output/regressions/Truncated_GDP_Regs_Unc_Fore, excel nor2 ///
					addstat(Adj R^2, `a_r2', Lags, `lag', Tstat, `tstat') ctitle("v`Dep'") append
			}

		restore
	}

*Hicp Regressions 
	import excel using output/results/hicp_full_100.xlsx, clear
	local i = 1
	foreach var of varlist * {
		rename `var' v`i'
		local i = `i' + 1
	}
	destring *, replace
	drop if v1 == 2014
	 
	
	*Truncate data 1991Q1 - 2007Q2
	drop if v1 > 2007
	drop if v1 == 2007 & v2 >2
	
	*set 2003Q2 to missing for V29
	//replace v29 = . if v1 == 2003 & v2 == 2 

	matrix define Independent = (9,8,12,11,15,14)
	matrix define Dependent = (18,29,21,30,24,31)
	matrix define Lags = (3,3,3,3,0,0)
	
	forvalues i=1/6 {
		preserve

		local Ind = Independent[1,`i']
		disp `Ind'
		local Dep = Dependent[1,`i']
		dis `Dep'
		local lag = Lags[1,`i']
		disp `lag'
		
			*drop missing values 
			drop if v`Ind' == . 
			drop if v`Dep' ==.
			*generate time variable
			egen t = group(v1 v2)
			tsset t

			reg v`Dep' v`Ind'
			local a_r2 = e(r2_a)
			newey v`Dep' v`Ind', lag(`lag')
			test v`Ind'=0
			local tstat = invttail(e(df_r),r(p)/2)

			if `i'==1 {
				outreg2 using output/regressions/Truncated_Hicp_Regs_Unc_Fore, excel nor2 ///
					addstat(Adj R^2, `a_r2', Lags, `lag', Tstat, `tstat') ctitle("v`Dep'") replace
			} 
			else {
				outreg2 using output/regressions/Truncated_Hicp_Regs_Unc_Fore, excel nor2 ///
					addstat(Adj R^2, `a_r2', Lags, `lag', Tstat, `tstat') ctitle("v`Dep'") append
			}

		restore
	}
*/
*Urate Regressions 
	import excel using output/results/urate_full_100.xlsx, clear
	local i = 1
	foreach var of varlist * {
		rename `var' v`i'
		local i = `i' + 1
	}
	destring *, replace
	drop if v1 == 2014
	
	*Truncate data 1991Q1 - 2007Q2
	drop if v1 > 2007
	drop if v1 == 2007 & v2 >2
	
	matrix define Independent = (9,8,12,11,15,14)
	matrix define Dependent = (18,29,21,30,24,31)
	matrix define Lags = (0,0,1,1,0,0)
	
	forvalues i=1/6 {
		preserve

		local Ind = Independent[1,`i']
		disp `Ind'
		local Dep = Dependent[1,`i']
		dis `Dep'
		local lag = Lags[1,`i']
		disp `lag'
		
			*drop missing values 
			drop if v`Ind' == . 
			drop if v`Dep' ==.
			*generate time variable
			egen t = group(v1 v2)
			tsset t

			reg v`Dep' v`Ind'
			local a_r2 = e(r2_a)
			newey v`Dep' v`Ind', lag(`lag')
			test v`Ind'=0
			local tstat = invttail(e(df_r),r(p)/2)

			if `i'==1 {
				outreg2 using output/regressions/Truncated_Urate_Regs_Unc_Fore, excel nor2 ///
					addstat(Adj R^2, `a_r2', Lags, `lag', Tstat, `tstat') ctitle("v`Dep'") replace
			} 
			else {
				outreg2 using output/regressions/Truncated_Urate_Regs_Unc_Fore, excel nor2 ///
					addstat(Adj R^2, `a_r2', Lags, `lag', Tstat, `tstat') ctitle("v`Dep'") append
			}

		restore
	}


